@@ -12,12 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-
 from ceilometer.agent import plugin_base as plugin
 
-cfg.CONF.import_group('service_credentials', 'ceilometer.keystone_client')
-
 
 class TenantDiscovery(plugin.DiscoveryBase):
     """Discovery that supplies keystone tenants.
