@@ -1,5 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2015-2016 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,23 +14,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import logging
 import os
+import uuid
 
 from oslo_config import cfg
 from oslo_log import log
 from paste import deploy
 import pecan
-from werkzeug import serving
 
 from ceilometer.api import hooks
 from ceilometer.api import middleware
-from ceilometer.i18n import _LI, _LW
 
 LOG = log.getLogger(__name__)
 
-CONF = cfg.CONF
-
 OPTS = [
     cfg.StrOpt('api_paste_config',
                default="api_paste.ini",
@@ -38,9 +35,6 @@ OPTS = [
 ]
 
 API_OPTS = [
-    cfg.BoolOpt('pecan_debug',
-                default=False,
-                help='Toggle Pecan Debug Middleware.'),
     cfg.IntOpt('default_api_return_limit',
                min=1,
                default=100,
@@ -48,15 +42,15 @@ API_OPTS = [
                ),
 ]
 
-CONF.register_opts(OPTS)
-CONF.register_opts(API_OPTS, group='api')
 
+def setup_app(pecan_config=None, conf=None):
+    if conf is None:
+        raise RuntimeError("No configuration passed")
 
-def setup_app(pecan_config=None):
     # FIXME: Replace DBHook with a hooks.TransactionHook
-    app_hooks = [hooks.ConfigHook(),
-                 hooks.DBHook(),
-                 hooks.NotifierHook(),
+    app_hooks = [hooks.ConfigHook(conf),
+                 hooks.DBHook(conf),
+                 hooks.NotifierHook(conf),
                  hooks.TranslationHook()]
 
     pecan_config = pecan_config or {
@@ -68,16 +62,8 @@ def setup_app(pecan_config=None):
 
     pecan.configuration.set_config(dict(pecan_config), overwrite=True)
 
-    # NOTE(sileht): pecan debug won't work in multi-process environment
-    pecan_debug = CONF.api.pecan_debug
-    if CONF.api.workers and CONF.api.workers != 1 and pecan_debug:
-        pecan_debug = False
-        LOG.warning(_LW('pecan_debug cannot be enabled, if workers is > 1, '
-                        'the value is overrided with False'))
-
     app = pecan.make_app(
         pecan_config['app']['root'],
-        debug=pecan_debug,
         hooks=app_hooks,
         wrap_app=middleware.ParsableErrorMiddleware,
         guess_content_type_from_ext=False
@@ -86,41 +72,41 @@ def setup_app(pecan_config=None):
     return app
 
 
-def load_app():
+# NOTE(sileht): pastedeploy uses ConfigParser to handle
+# global_conf, since python 3 ConfigParser doesn't
+# allow to store object as config value, only strings are
+# permit, so to be able to pass an object created before paste load
+# the app, we store them into a global var. But the each loaded app
+# store it's configuration in unique key to be concurrency safe.
+global APPCONFIGS
+APPCONFIGS = {}
+
+
+def load_app(conf):
+    global APPCONFIGS
+
     # Build the WSGI app
     cfg_file = None
-    cfg_path = cfg.CONF.api_paste_config
+    cfg_path = conf.api_paste_config
     if not os.path.isabs(cfg_path):
-        cfg_file = CONF.find_file(cfg_path)
+        cfg_file = conf.find_file(cfg_path)
     elif os.path.exists(cfg_path):
         cfg_file = cfg_path
 
     if not cfg_file:
-        raise cfg.ConfigFilesNotFoundError([cfg.CONF.api_paste_config])
-    LOG.info("Full WSGI config used: %s" % cfg_file)
-    return deploy.loadapp("config:" + cfg_file)
+        raise cfg.ConfigFilesNotFoundError([conf.api_paste_config])
 
+    configkey = str(uuid.uuid4())
+    APPCONFIGS[configkey] = conf
 
-def build_server():
-    app = load_app()
-    # Create the WSGI server and start it
-    host, port = cfg.CONF.api.host, cfg.CONF.api.port
-
-    LOG.info(_LI('Starting server in PID %s') % os.getpid())
-    LOG.info(_LI("Configuration:"))
-    cfg.CONF.log_opt_values(LOG, logging.INFO)
-
-    if host == '0.0.0.0':
-        LOG.info(_LI(
-            'serving on 0.0.0.0:%(sport)s, view at http://127.0.0.1:%(vport)s')
-            % ({'sport': port, 'vport': port}))
-    else:
-        LOG.info(_LI("serving on http://%(host)s:%(port)s") % (
-                 {'host': host, 'port': port}))
-
-    serving.run_simple(cfg.CONF.api.host, cfg.CONF.api.port,
-                       app, processes=CONF.api.workers)
+    LOG.info("Full WSGI config used: %s", cfg_file)
+    LOG.warning("Note: Ceilometer API is deprecated; use APIs from "
+                "Aodh (alarms), Gnocchi (metrics) and/or Panko (events).")
+    return deploy.loadapp("config:" + cfg_file,
+                          global_conf={'configkey': configkey})
 
 
 def app_factory(global_config, **local_conf):
-    return setup_app()
+    global APPCONFIGS
+    conf = APPCONFIGS.get(global_config.get('configkey'))
+    return setup_app(conf=conf)
