@@ -30,7 +30,7 @@ class BaseComputePollster(plugin_base.PollsterBase):
         try:
             inspector = self._inspector
         except AttributeError:
-            inspector = virt_inspector.get_hypervisor_inspector()
+            inspector = virt_inspector.get_hypervisor_inspector(self.conf)
             BaseComputePollster._inspector = inspector
         return inspector
 
@@ -72,12 +72,12 @@ class BaseComputePollster(plugin_base.PollsterBase):
         self._last_poll_time = current_time
         return duration
 
-    @staticmethod
-    def _get_samples_per_devices(attribute, instance, _name, _type, _unit,
-                                 monotonic_time=None):
+    def _get_samples_per_devices(self, attribute, instance, _name, _type,
+                                 _unit):
         samples = []
         for disk, value in six.iteritems(attribute):
             samples.append(util.make_sample_from_instance(
+                self.conf,
                 instance,
                 name=_name,
                 type=_type,
@@ -85,6 +85,5 @@ class BaseComputePollster(plugin_base.PollsterBase):
                 volume=value,
                 resource_id="%s-%s" % (instance.id, disk),
                 additional_metadata={'disk_name': disk},
-                monotonic_time=monotonic_time,
             ))
         return samples
