@@ -14,8 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
-import monotonic
 from oslo_log import log
 
 import ceilometer
@@ -41,13 +39,13 @@ class CPUPollster(pollsters.BaseComputePollster):
                            'time': cpu_info.time})
                 cpu_num = {'cpu_number': cpu_info.number}
                 yield util.make_sample_from_instance(
+                    self.conf,
                     instance,
                     name='cpu',
                     type=sample.TYPE_CUMULATIVE,
                     unit='ns',
                     volume=cpu_info.time,
                     additional_metadata=cpu_num,
-                    monotonic_time=monotonic.monotonic()
                 )
             except virt_inspector.InstanceNotFoundException as err:
                 # Instance was deleted while getting samples. Ignore it.
@@ -80,6 +78,7 @@ class CPUUtilPollster(pollsters.BaseComputePollster):
                           {'instance': instance,
                            'util': cpu_info.util})
                 yield util.make_sample_from_instance(
+                    self.conf,
                     instance,
                     name='cpu_util',
                     type=sample.TYPE_GAUGE,
@@ -110,6 +109,7 @@ class CPUL3CachePollster(pollsters.BaseComputePollster):
                           ({'id': instance.id,
                             'cache_size': cpu_cache.l3_cache_usage}))
                 yield util.make_sample_from_instance(
+                    self.conf,
                     instance,
                     name='cpu_l3_cache',
                     type=sample.TYPE_GAUGE,
