@@ -17,7 +17,6 @@
 import abc
 import collections
 
-import monotonic
 from oslo_log import log
 import six
 
@@ -34,7 +33,7 @@ LOG = log.getLogger(__name__)
 
 DiskIOData = collections.namedtuple(
     'DiskIOData',
-    'r_bytes r_requests w_bytes w_requests per_disk_requests polled_time',
+    'r_bytes r_requests w_bytes w_requests per_disk_requests',
 )
 
 DiskRateData = collections.namedtuple('DiskRateData',
@@ -104,14 +103,12 @@ class _Base(pollsters.BaseComputePollster):
                 'write_bytes': per_device_write_bytes,
                 'write_requests': per_device_write_requests,
             }
-            polled_time = monotonic.monotonic()
             i_cache[instance.id] = DiskIOData(
                 r_bytes=r_bytes,
                 r_requests=r_requests,
                 w_bytes=w_bytes,
                 w_requests=w_requests,
                 per_disk_requests=per_device_requests,
-                polled_time=polled_time
             )
         return i_cache[instance.id]
 
@@ -119,11 +116,11 @@ class _Base(pollsters.BaseComputePollster):
     def _get_samples(instance, c_data):
         """Return one or more Sample."""
 
-    @staticmethod
-    def _get_sample_read_and_write(instance, _name, _unit, c_data,
+    def _get_sample_read_and_write(self, instance, _name, _unit, c_data,
                                    _volume, _metadata):
         """Read / write Pollster and return one Sample"""
         return [util.make_sample_from_instance(
+            self.conf,
             instance,
             name=_name,
             type=sample.TYPE_CUMULATIVE,
@@ -131,15 +128,13 @@ class _Base(pollsters.BaseComputePollster):
             volume=getattr(c_data, _volume),
             additional_metadata={
                 'device': c_data.per_disk_requests[_metadata].keys()},
-            monotonic_time=c_data.polled_time,
         )]
 
     def _get_samples_per_device(self, c_data, _attr, instance, _name, _unit):
         """Return one or more Samples for meter 'disk.device.*'"""
         return self._get_samples_per_devices(c_data.per_disk_requests[_attr],
                                              instance, _name,
-                                             sample.TYPE_CUMULATIVE, _unit,
-                                             c_data.polled_time)
+                                             sample.TYPE_CUMULATIVE, _unit)
 
     def get_samples(self, manager, cache, resources):
         for instance in resources:
@@ -321,6 +316,7 @@ class _DiskRatesPollsterBase(pollsters.BaseComputePollster):
                                    _attr1, _attr2):
         """Read / write Pollster and return one Sample"""
         return [util.make_sample_from_instance(
+            self.conf,
             instance,
             name=_name,
             type=sample.TYPE_GAUGE,
@@ -351,7 +347,7 @@ class ReadRequestsRatePollster(_DiskRatesPollsterBase):
 
     def _get_samples(self, instance, disk_rates_info):
         return self._get_sample_read_and_write(
-            instance, 'disk.read.requests.rate', 'requests/s', disk_rates_info,
+            instance, 'disk.read.requests.rate', 'request/s', disk_rates_info,
             'read_requests_rate', 'per_disk_rate')
 
 
@@ -360,7 +356,7 @@ class PerDeviceReadRequestsRatePollster(_DiskRatesPollsterBase):
     def _get_samples(self, instance, disk_rates_info):
         return self._get_samples_per_device(
             disk_rates_info, 'read_requests_rate', instance,
-            'disk.device.read.requests.rate', 'requests/s')
+            'disk.device.read.requests.rate', 'request/s')
 
 
 class WriteBytesRatePollster(_DiskRatesPollsterBase):
@@ -383,7 +379,7 @@ class WriteRequestsRatePollster(_DiskRatesPollsterBase):
 
     def _get_samples(self, instance, disk_rates_info):
         return self._get_sample_read_and_write(
-            instance, 'disk.write.requests.rate', 'requests/s',
+            instance, 'disk.write.requests.rate', 'request/s',
             disk_rates_info, 'write_requests_rate', 'per_disk_rate')
 
 
@@ -392,7 +388,7 @@ class PerDeviceWriteRequestsRatePollster(_DiskRatesPollsterBase):
     def _get_samples(self, instance, disk_rates_info):
         return self._get_samples_per_device(
             disk_rates_info, 'write_requests_rate', instance,
-            'disk.device.write.requests.rate', 'requests/s')
+            'disk.device.write.requests.rate', 'request/s')
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -441,6 +437,7 @@ class DiskLatencyPollster(_DiskLatencyPollsterBase):
 
     def _get_samples(self, instance, disk_latency_info):
         return [util.make_sample_from_instance(
+            self.conf,
             instance,
             name='disk.latency',
             type=sample.TYPE_GAUGE,
@@ -456,6 +453,7 @@ class PerDeviceDiskLatencyPollster(_DiskLatencyPollsterBase):
         for disk, value in six.iteritems(disk_latency_info.per_disk_latency[
                 'disk_latency']):
             samples.append(util.make_sample_from_instance(
+                self.conf,
                 instance,
                 name='disk.device.latency',
                 type=sample.TYPE_GAUGE,
@@ -512,6 +510,7 @@ class DiskIOPSPollster(_DiskIOPSPollsterBase):
 
     def _get_samples(self, instance, disk_iops_info):
         return [util.make_sample_from_instance(
+            self.conf,
             instance,
             name='disk.iops',
             type=sample.TYPE_GAUGE,
@@ -527,6 +526,7 @@ class PerDeviceDiskIOPSPollster(_DiskIOPSPollsterBase):
         for disk, value in six.iteritems(disk_iops_info.per_disk_iops[
                 'iops_count']):
             samples.append(util.make_sample_from_instance(
+                self.conf,
                 instance,
                 name='disk.device.iops',
                 type=sample.TYPE_GAUGE,
@@ -584,6 +584,7 @@ class _DiskInfoPollsterBase(pollsters.BaseComputePollster):
         samples = []
         for disk, value in six.iteritems(disk_info.per_disk_info[_attr]):
             samples.append(util.make_sample_from_instance(
+                self.conf,
                 instance,
                 name=_name,
                 type=sample.TYPE_GAUGE,
@@ -597,6 +598,7 @@ class _DiskInfoPollsterBase(pollsters.BaseComputePollster):
     def _get_samples_task(self, instance, _name, disk_info, _attr1, _attr2):
         """Return one or more Samples for meter 'disk.task.*'."""
         return [util.make_sample_from_instance(
+            self.conf,
             instance,
             name=_name,
             type=sample.TYPE_GAUGE,
