@@ -16,7 +16,6 @@
 
 import copy
 
-import monotonic
 from oslo_log import log
 
 import ceilometer
@@ -35,9 +34,7 @@ class _Base(pollsters.BaseComputePollster):
     NET_USAGE_MESSAGE = ' '.join(["NETWORK USAGE:", "%s %s:", "read-bytes=%d",
                                   "write-bytes=%d"])
 
-    @staticmethod
-    def make_vnic_sample(instance, name, type, unit, volume, vnic_data,
-                         monotonic_time):
+    def make_vnic_sample(self, instance, name, type, unit, volume, vnic_data):
         metadata = copy.copy(vnic_data)
         additional_metadata = dict(zip(metadata._fields, metadata))
         if vnic_data.fref is not None:
@@ -49,14 +46,14 @@ class _Base(pollsters.BaseComputePollster):
             additional_metadata['vnic_name'] = vnic_data.name
 
         return util.make_sample_from_instance(
+            conf=self.conf,
             instance=instance,
             name=name,
             type=type,
             unit=unit,
             volume=volume,
             resource_id=rid,
-            additional_metadata=additional_metadata,
-            monotonic_time=monotonic_time,
+            additional_metadata=additional_metadata
         )
 
     CACHE_KEY_VNIC = 'vnics'
@@ -75,10 +72,9 @@ class _Base(pollsters.BaseComputePollster):
     def _get_vnics_for_instance(self, cache, inspector, instance):
         i_cache = cache.setdefault(self.CACHE_KEY_VNIC, {})
         if instance.id not in i_cache:
-            data = list(self._get_vnic_info(inspector, instance))
-            polled_time = monotonic.monotonic()
-            i_cache[instance.id] = [(vnic, info, polled_time)
-                                    for vnic, info in data]
+            i_cache[instance.id] = list(
+                self._get_vnic_info(inspector, instance)
+            )
         return i_cache[instance.id]
 
     def get_samples(self, manager, cache, resources):
@@ -92,11 +88,11 @@ class _Base(pollsters.BaseComputePollster):
                     self.inspector,
                     instance,
                 )
-                for vnic, info, polled_time in vnics:
+                for vnic, info in vnics:
                     LOG.debug(self.NET_USAGE_MESSAGE, instance_name,
                               vnic.name, self._get_rx_info(info),
                               self._get_tx_info(info))
-                    yield self._get_sample(instance, vnic, info, polled_time)
+                    yield self._get_sample(instance, vnic, info)
             except virt_inspector.InstanceNotFoundException as err:
                 # Instance was deleted while getting samples. Ignore it.
                 LOG.debug('Exception while getting samples %s', err)
@@ -108,7 +104,7 @@ class _Base(pollsters.BaseComputePollster):
             except ceilometer.NotImplementedError:
                 # Selected inspector does not implement this pollster.
                 LOG.debug('%(inspector)s does not provide data for '
-                          ' %(pollster)s',
+                          '%(pollster)s',
                           {'inspector': self.inspector.__class__.__name__,
                            'pollster': self.__class__.__name__})
                 raise plugin_base.PollsterPermanentError(resources)
@@ -153,9 +149,37 @@ class _PacketsBase(_Base):
         return info.tx_packets
 
 
+class _DropBase(_Base):
+
+    NET_USAGE_MESSAGE = ' '.join(["NETWORK PACKET DROPS:", "%s %s:",
+                                  "rx-drop=%d", "tx-drop=%d"])
+
+    @staticmethod
+    def _get_rx_info(info):
+        return info.rx_drop
+
+    @staticmethod
+    def _get_tx_info(info):
+        return info.tx_drop
+
+
+class _ErrorsBase(_Base):
+
+    NET_USAGE_MESSAGE = ' '.join(["NETWORK PACKET ERRORS:", "%s %s:",
+                                  "rx-errors=%d", "tx-errors=%d"])
+
+    @staticmethod
+    def _get_rx_info(info):
+        return info.rx_errors
+
+    @staticmethod
+    def _get_tx_info(info):
+        return info.tx_errors
+
+
 class IncomingBytesPollster(_Base):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.incoming.bytes',
@@ -163,13 +187,12 @@ class IncomingBytesPollster(_Base):
             unit='B',
             volume=info.rx_bytes,
             vnic_data=vnic,
-            monotonic_time=polled_time,
         )
 
 
 class IncomingPacketsPollster(_PacketsBase):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.incoming.packets',
@@ -177,13 +200,12 @@ class IncomingPacketsPollster(_PacketsBase):
             unit='packet',
             volume=info.rx_packets,
             vnic_data=vnic,
-            monotonic_time=polled_time,
         )
 
 
 class OutgoingBytesPollster(_Base):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.outgoing.bytes',
@@ -191,13 +213,12 @@ class OutgoingBytesPollster(_Base):
             unit='B',
             volume=info.tx_bytes,
             vnic_data=vnic,
-            monotonic_time=polled_time,
         )
 
 
 class OutgoingPacketsPollster(_PacketsBase):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.outgoing.packets',
@@ -205,13 +226,12 @@ class OutgoingPacketsPollster(_PacketsBase):
             unit='packet',
             volume=info.tx_packets,
             vnic_data=vnic,
-            monotonic_time=polled_time,
         )
 
 
 class IncomingBytesRatePollster(_RateBase):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.incoming.bytes.rate',
@@ -219,13 +239,12 @@ class IncomingBytesRatePollster(_RateBase):
             unit='B/s',
             volume=info.rx_bytes_rate,
             vnic_data=vnic,
-            monotonic_time=polled_time,
         )
 
 
 class OutgoingBytesRatePollster(_RateBase):
 
-    def _get_sample(self, instance, vnic, info, polled_time):
+    def _get_sample(self, instance, vnic, info):
         return self.make_vnic_sample(
             instance,
             name='network.outgoing.bytes.rate',
@@ -233,5 +252,56 @@ class OutgoingBytesRatePollster(_RateBase):
             unit='B/s',
             volume=info.tx_bytes_rate,
             vnic_data=vnic,
-            monotonic_time=polled_time,
+        )
+
+
+class IncomingDropPollster(_DropBase):
+
+    def _get_sample(self, instance, vnic, info):
+        return self.make_vnic_sample(
+            instance,
+            name='network.incoming.packets.drop',
+            type=sample.TYPE_CUMULATIVE,
+            unit='packet',
+            volume=info.rx_drop,
+            vnic_data=vnic,
+        )
+
+
+class OutgoingDropPollster(_DropBase):
+
+    def _get_sample(self, instance, vnic, info):
+        return self.make_vnic_sample(
+            instance,
+            name='network.outgoing.packets.drop',
+            type=sample.TYPE_CUMULATIVE,
+            unit='packet',
+            volume=info.tx_drop,
+            vnic_data=vnic,
+        )
+
+
+class IncomingErrorsPollster(_ErrorsBase):
+
+    def _get_sample(self, instance, vnic, info):
+        return self.make_vnic_sample(
+            instance,
+            name='network.incoming.packets.error',
+            type=sample.TYPE_CUMULATIVE,
+            unit='packet',
+            volume=info.rx_errors,
+            vnic_data=vnic,
+        )
+
+
+class OutgoingErrorsPollster(_ErrorsBase):
+
+    def _get_sample(self, instance, vnic, info):
+        return self.make_vnic_sample(
+            instance,
+            name='network.outgoing.packets.error',
+            type=sample.TYPE_CUMULATIVE,
+            unit='packet',
+            volume=info.tx_errors,
+            vnic_data=vnic,
         )
