@@ -77,8 +77,8 @@ exception_conversion_map = collections.OrderedDict([
 @decorate_all_methods(convert_exceptions, exception_conversion_map)
 class HyperVInspector(virt_inspector.Inspector):
 
-    def __init__(self):
-        super(HyperVInspector, self).__init__()
+    def __init__(self, conf):
+        super(HyperVInspector, self).__init__(conf)
         self._utils = utilsfactory.get_metricsutils()
         self._host_max_cpu_clock = self._compute_host_max_cpu_clock()
 
@@ -120,8 +120,12 @@ class HyperVInspector(virt_inspector.Inspector):
             stats = virt_inspector.InterfaceStats(
                 rx_bytes=vnic_metrics['rx_mb'] * units.Mi,
                 rx_packets=0,
+                rx_drop=0,
+                rx_errors=0,
                 tx_bytes=vnic_metrics['tx_mb'] * units.Mi,
-                tx_packets=0)
+                tx_packets=0,
+                tx_drop=0,
+                tx_errors=0)
 
             yield (interface, stats)
 
