@@ -15,80 +15,36 @@
 """Implementation of Inspector abstraction for libvirt."""
 
 from lxml import etree
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import units
 import six
 
+try:
+    import libvirt
+except ImportError:
+    libvirt = None
+
 from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt import inspector as virt_inspector
+from ceilometer.compute.virt.libvirt import utils as libvirt_utils
 from ceilometer.i18n import _LW, _LE, _
 
-libvirt = None
-
 LOG = logging.getLogger(__name__)
 
-OPTS = [
-    cfg.StrOpt('libvirt_type',
-               default='kvm',
-               choices=['kvm', 'lxc', 'qemu', 'uml', 'xen'],
-               help='Libvirt domain type.'),
-    cfg.StrOpt('libvirt_uri',
-               default='',
-               help='Override the default libvirt URI '
-                    '(which is dependent on libvirt_type).'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(OPTS)
-
-
-def retry_on_disconnect(function):
-    def decorator(self, *args, **kwargs):
-        try:
-            return function(self, *args, **kwargs)
-        except ImportError:
-            # NOTE(sileht): in case of libvirt failed to be imported
-            raise
-        except libvirt.libvirtError as e:
-            if (e.get_error_code() in (libvirt.VIR_ERR_SYSTEM_ERROR,
-                                       libvirt.VIR_ERR_INTERNAL_ERROR) and
-                e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
-                                         libvirt.VIR_FROM_RPC)):
-                LOG.debug('Connection to libvirt broken')
-                self.connection = None
-                return function(self, *args, **kwargs)
-            else:
-                raise
-    return decorator
-
 
 class LibvirtInspector(virt_inspector.Inspector):
 
-    per_type_uris = dict(uml='uml:///system', xen='xen:///', lxc='lxc:///')
-
-    def __init__(self):
+    def __init__(self, conf):
+        super(LibvirtInspector, self).__init__(conf)
         self._connection = None
 
     @property
     def connection(self):
         if not self._connection:
-            global libvirt
-            if libvirt is None:
-                libvirt = __import__('libvirt')
-
-            uri = (CONF.libvirt_uri or
-                   self.per_type_uris.get(CONF.libvirt_type, 'qemu:///system'))
-            LOG.debug('Connecting to libvirt: %s', uri)
-            self._connection = libvirt.openReadOnly(uri)
-
+            self._connection = libvirt_utils.get_libvirt_connection(self.conf)
         return self._connection
 
-    @connection.setter
-    def connection(self, value):
-        self._connection = value
-
-    @retry_on_disconnect
+    @libvirt_utils.retry_on_disconnect
     def _lookup_by_uuid(self, instance):
         instance_name = util.instance_name(instance)
         try:
@@ -115,30 +71,10 @@ class LibvirtInspector(virt_inspector.Inspector):
         domain = self._get_domain_not_shut_off_or_raise(instance)
         # TODO(gordc): this can probably be cached since it can be used to get
         # all data related
-        stats = self.connection.domainListGetStats([domain], 0)[0][1]
-        cpu_time = 0
-        current_cpus = stats.get('vcpu.current')
-        # Iterate over the maximum number of CPUs here, and count the
-        # actual number encountered, since the vcpu.x structure can
-        # have holes according to
-        # https://libvirt.org/git/?p=libvirt.git;a=blob;f=src/libvirt-domain.c
-        # virConnectGetAllDomainStats()
-        for vcpu in six.moves.range(stats.get('vcpu.maximum', 0)):
-            try:
-                cpu_time += (stats.get('vcpu.%s.time' % vcpu) +
-                             stats.get('vcpu.%s.wait' % vcpu))
-                current_cpus -= 1
-            except TypeError:
-                # pass here, if there are too many holes, the cpu count will
-                # not match, so don't need special error handling.
-                pass
-
-        if current_cpus:
-            # There wasn't enough data, so fall back
-            cpu_time = stats.get('cpu.time')
-
-        return virt_inspector.CPUStats(number=stats['vcpu.current'],
-                                       time=cpu_time)
+        stats = self.connection.domainListGetStats([domain])
+        dom_stat = stats[0][1]
+        return virt_inspector.CPUStats(number=dom_stat['vcpu.current'],
+                                       time=dom_stat['cpu.time'])
 
     def inspect_cpu_l3_cache(self, instance):
         domain = self._lookup_by_uuid(instance)
@@ -206,8 +142,12 @@ class LibvirtInspector(virt_inspector.Inspector):
             dom_stats = domain.interfaceStats(name)
             stats = virt_inspector.InterfaceStats(rx_bytes=dom_stats[0],
                                                   rx_packets=dom_stats[1],
+                                                  rx_drop=dom_stats[2],
+                                                  rx_errors=dom_stats[3],
                                                   tx_bytes=dom_stats[4],
-                                                  tx_packets=dom_stats[5])
+                                                  tx_packets=dom_stats[5],
+                                                  tx_drop=dom_stats[6],
+                                                  tx_errors=dom_stats[7])
             yield (interface, stats)
 
     def inspect_disks(self, instance):
@@ -267,6 +207,11 @@ class LibvirtInspector(virt_inspector.Inspector):
                             '%(instance_uuid)s unsupported by libvirt') % {
                             'instance_uuid': instance.id})
                     continue
+                # NOTE(lhx): "cdrom" device associated to the configdrive
+                # no longer has a "source" element. Releated bug:
+                # https://bugs.launchpad.net/ceilometer/+bug/1622718
+                if disk.find('source') is None:
+                    continue
                 target = disk.find('target')
                 device = target.get('dev')
                 if device:
