@@ -18,7 +18,7 @@ import uuid
 
 from oslo_config import cfg
 from oslo_log import log
-import retrying
+import tenacity
 import tooz.coordination
 
 from ceilometer.i18n import _LE, _LI, _LW
@@ -43,14 +43,13 @@ OPTS = [
                       'membership has changed'),
     cfg.IntOpt('retry_backoff',
                default=1,
-               help='Retry backoff factor when retrying to connect with'
+               help='Retry backoff factor when retrying to connect with '
                     'coordination backend'),
     cfg.IntOpt('max_retry_interval',
                default=30,
                help='Maximum number of seconds between retry to join '
                     'partitioning group')
 ]
-cfg.CONF.register_opts(OPTS, group='coordination')
 
 
 class ErrorJoiningPartitioningGroup(Exception):
@@ -67,14 +66,6 @@ class MemberNotInGroupError(Exception):
             {'group_id': group_id, 'members': members, 'me': my_id})
 
 
-def retry_on_error_joining_partition(exception):
-    return isinstance(exception, ErrorJoiningPartitioningGroup)
-
-
-def retry_on_member_not_in_group(exception):
-    return isinstance(exception, MemberNotInGroupError)
-
-
 class PartitionCoordinator(object):
     """Workload partitioning coordinator.
 
@@ -89,13 +80,14 @@ class PartitionCoordinator(object):
     empty iterable in this case.
     """
 
-    def __init__(self, my_id=None):
+    def __init__(self, conf, my_id=None):
+        self.conf = conf
         self._coordinator = None
         self._groups = set()
         self._my_id = my_id or str(uuid.uuid4())
 
     def start(self):
-        backend_url = cfg.CONF.coordination.backend_url
+        backend_url = self.conf.coordination.backend_url
         if backend_url:
             try:
                 self._coordinator = tooz.coordination.get_coordinator(
@@ -147,14 +139,12 @@ class PartitionCoordinator(object):
                 or not group_id):
             return
 
-        retry_backoff = cfg.CONF.coordination.retry_backoff * 1000
-        max_retry_interval = cfg.CONF.coordination.max_retry_interval * 1000
-
-        @retrying.retry(
-            wait_exponential_multiplier=retry_backoff,
-            wait_exponential_max=max_retry_interval,
-            retry_on_exception=retry_on_error_joining_partition,
-            wrap_exception=True)
+        @tenacity.retry(
+            wait=tenacity.wait_exponential(
+                multiplier=self.conf.coordination.retry_backoff,
+                max=self.conf.coordination.max_retry_interval),
+            retry=tenacity.retry_if_exception_type(
+                ErrorJoiningPartitioningGroup))
         def _inner():
             try:
                 join_req = self._coordinator.join_group(group_id)
@@ -196,9 +186,12 @@ class PartitionCoordinator(object):
             except tooz.coordination.GroupNotCreated:
                 self.join_group(group_id)
 
-    @retrying.retry(stop_max_attempt_number=5, wait_random_max=2000,
-                    retry_on_exception=retry_on_member_not_in_group)
-    def extract_my_subset(self, group_id, iterable, attempt=0):
+    @tenacity.retry(
+        wait=tenacity.wait_random(max=2),
+        stop=tenacity.stop_after_attempt(5),
+        retry=tenacity.retry_if_exception_type(MemberNotInGroupError),
+        reraise=True)
+    def extract_my_subset(self, group_id, iterable):
         """Filters an iterable, returning only objects assigned to this agent.
 
         We have a list of objects and get a list of active group members from
