@@ -13,16 +13,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from debtcollector import moves
 from oslo_config import cfg
 from oslo_log import log
+from oslo_utils import fnmatch
 from oslo_utils import timeutils
 import six
 
 from ceilometer import declarative
 from ceilometer.event.storage import models
 from ceilometer.i18n import _
-from ceilometer import utils
 
 OPTS = [
     cfg.StrOpt('definitions_cfg_file',
@@ -40,16 +39,8 @@ OPTS = [
                     'not captured.')
 ]
 
-cfg.CONF.register_opts(OPTS, group='event')
-
 LOG = log.getLogger(__name__)
 
-EventDefinitionException = moves.moved_class(declarative.DefinitionException,
-                                             'EventDefinitionException',
-                                             __name__,
-                                             version=6.0,
-                                             removal_version="?")
-
 
 class TraitDefinition(declarative.Definition):
     def __init__(self, name, trait_cfg, plugin_manager):
@@ -58,7 +49,7 @@ class TraitDefinition(declarative.Definition):
                      if isinstance(trait_cfg, dict) else 'text')
         self.trait_type = models.Trait.get_type_by_name(type_name)
         if self.trait_type is None:
-            raise declarative.DefinitionException(
+            raise declarative.EventDefinitionException(
                 _("Invalid trait type '%(type)s' for trait %(trait)s")
                 % dict(type=type_name, trait=name), self.cfg)
 
@@ -91,18 +82,18 @@ class EventDefinition(object):
                                             '_context_tenant']),
     )
 
-    def __init__(self, definition_cfg, trait_plugin_mgr):
+    def __init__(self, definition_cfg, trait_plugin_mgr, raw_levels):
         self._included_types = []
         self._excluded_types = []
         self.traits = dict()
         self.cfg = definition_cfg
-        self.raw_levels = [level.lower() for level in cfg.CONF.event.store_raw]
+        self.raw_levels = raw_levels
 
         try:
             event_type = definition_cfg['event_type']
             traits = definition_cfg['traits']
         except KeyError as err:
-            raise declarative.DefinitionException(
+            raise declarative.EventDefinitionException(
                 _("Required field %s not specified") % err.args[0], self.cfg)
 
         if isinstance(event_type, six.string_types):
@@ -130,13 +121,13 @@ class EventDefinition(object):
 
     def included_type(self, event_type):
         for t in self._included_types:
-            if utils.match(event_type, t):
+            if fnmatch.fnmatch(event_type, t):
                 return True
         return False
 
     def excluded_type(self, event_type):
         for t in self._excluded_types:
-            if utils.match(event_type, t):
+            if fnmatch.fnmatch(event_type, t):
                 return True
         return False
 
@@ -261,14 +252,20 @@ class NotificationEventsConverter(object):
 
     """
 
-    def __init__(self, events_config, trait_plugin_mgr, add_catchall=True):
+    def __init__(self, conf, events_config, trait_plugin_mgr):
+        self.conf = conf
+
+        raw_levels = [level.lower() for level in self.conf.event.store_raw]
         self.definitions = [
-            EventDefinition(event_def, trait_plugin_mgr)
+            EventDefinition(event_def, trait_plugin_mgr, raw_levels)
             for event_def in reversed(events_config)]
+
+        add_catchall = not self.conf.event.drop_unmatched_notifications
         if add_catchall and not any(d.is_catchall for d in self.definitions):
             event_def = dict(event_type='*', traits={})
             self.definitions.append(EventDefinition(event_def,
-                                                    trait_plugin_mgr))
+                                                    trait_plugin_mgr,
+                                                    raw_levels))
 
     def to_event(self, notification_body):
         event_type = notification_body['event_type']
@@ -282,7 +279,7 @@ class NotificationEventsConverter(object):
         if edef is None:
             msg = (_('Dropping Notification %(type)s (uuid:%(msgid)s)')
                    % dict(type=event_type, msgid=message_id))
-            if cfg.CONF.event.drop_unmatched_notifications:
+            if self.conf.event.drop_unmatched_notifications:
                 LOG.debug(msg)
             else:
                 # If drop_unmatched_notifications is False, this should
@@ -293,9 +290,10 @@ class NotificationEventsConverter(object):
         return edef.to_event(notification_body)
 
 
-def setup_events(trait_plugin_mgr):
+def setup_events(conf, trait_plugin_mgr):
     """Setup the event definitions from yaml config file."""
     return NotificationEventsConverter(
-        declarative.load_definitions([], cfg.CONF.event.definitions_cfg_file),
-        trait_plugin_mgr,
-        add_catchall=not cfg.CONF.event.drop_unmatched_notifications)
+        conf,
+        declarative.load_definitions(conf, [],
+                                     conf.event.definitions_cfg_file),
+        trait_plugin_mgr)
