@@ -24,6 +24,7 @@ system power and temperature data based on ipmitool.
 import binascii
 import collections
 import tempfile
+import threading
 import time
 
 from oslo_config import cfg
@@ -42,9 +43,6 @@ OPTS = [
 ]
 
 
-CONF = cfg.CONF
-CONF.register_opts(OPTS, group='ipmi')
-
 IPMICMD = {"sdr_dump": "sdr dump",
            "sdr_info": "sdr info",
            "sensor_dump": "sdr -v"}
@@ -143,26 +141,25 @@ class NodeManager(object):
     compute node. It uses ipmitool to execute the IPMI command and parse
     the output into dict.
     """
-    _inited = False
     _instance = None
+    _instance_lock = threading.Lock()
 
     def __new__(cls, *args, **kwargs):
         """Singleton to avoid duplicated initialization."""
-        if not cls._instance:
-            cls._instance = super(NodeManager, cls).__new__(cls, *args,
-                                                            **kwargs)
+        if cls._instance:
+            # Shortcut with no lock
+            return cls._instance
+        with cls._instance_lock:
+            if not cls._instance:
+                cls._instance = super(NodeManager, cls).__new__(
+                    cls, *args, **kwargs)
         return cls._instance
 
-    def __init__(self):
-        if not (self._instance and self._inited):
-            # As singleton, only the 1st NM pollster would trigger its
-            # initialization. nm_version indicate init result, and is shared
-            # across all pollsters
-            self._inited = True
-            self.nm_version = 0
-            self.channel_slave = ''
-
-            self.nm_version = self.check_node_manager()
+    def __init__(self, conf):
+        self.conf = conf
+        self.nm_version = 0
+        self.channel_slave = ''
+        self.nm_version = self.check_node_manager()
 
     @staticmethod
     def _parse_slave_and_channel(file_path):
@@ -288,7 +285,7 @@ class NodeManager(object):
         if self._init_sensor_agent_process()['ret'] == ['01']:
             return
         # Run sensor initialization agent
-        for i in range(CONF.ipmi.node_manager_init_retry):
+        for i in range(self.conf.ipmi.node_manager_init_retry):
             self._init_sensor_agent()
             time.sleep(1)
             if self._init_sensor_agent_process()['ret'] == ['01']:
