@@ -29,14 +29,12 @@ import six
 from stevedore import extension
 import yaml
 
-
 from ceilometer.event.storage import models
-from ceilometer.i18n import _, _LI, _LW
+from ceilometer.i18n import _LI, _LW, _LE
 from ceilometer import publisher
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import sample as sample_util
 
-
 OPTS = [
     cfg.StrOpt('pipeline_cfg_file',
                default="pipeline.yaml",
@@ -61,18 +59,28 @@ OPTS = [
                ),
 ]
 
-cfg.CONF.register_opts(OPTS)
 
 LOG = log.getLogger(__name__)
 
 
-class PipelineException(Exception):
-    def __init__(self, message, pipeline_cfg):
+class ConfigException(Exception):
+    def __init__(self, cfg_type, message, cfg):
+        self.cfg_type = cfg_type
         self.msg = message
-        self.pipeline_cfg = pipeline_cfg
+        self.cfg = cfg
 
     def __str__(self):
-        return 'Pipeline %s: %s' % (self.pipeline_cfg, self.msg)
+        return '%s %s: %s' % (self.cfg_type, self.cfg, self.msg)
+
+
+class PollingException(ConfigException):
+    def __init__(self, message, cfg):
+        super(PollingException, self).__init__('Polling', message, cfg)
+
+
+class PipelineException(ConfigException):
+    def __init__(self, message, cfg):
+        super(PipelineException, self).__init__('Pipeline', message, cfg)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -82,6 +90,7 @@ class PipelineEndpoint(object):
         self.filter_rule = oslo_messaging.NotificationFilter(
             publisher_id=pipeline.name)
         self.publish_context = PublishContext([pipeline])
+        self.conf = pipeline.conf
 
     @abc.abstractmethod
     def sample(self, messages):
@@ -101,12 +110,9 @@ class SamplePipelineEndpoint(PipelineEndpoint):
                                resource_id=s['resource_id'],
                                timestamp=s['timestamp'],
                                resource_metadata=s['resource_metadata'],
-                               source=s.get('source'),
-                               # NOTE(sileht): May come from an older node,
-                               # Put None in this case.
-                               monotonic_time=s.get('monotonic_time'))
+                               source=s.get('source'))
             for s in samples if publisher_utils.verify_signature(
-                s, cfg.CONF.publisher.telemetry_secret)
+                s, self.conf.publisher.telemetry_secret)
         ]
         with self.publish_context as p:
             p(sorted(samples, key=methodcaller('get_iso_timestamp')))
@@ -126,20 +132,21 @@ class EventPipelineEndpoint(PipelineEndpoint):
                         for name, dtype, value in ev['traits']],
                 raw=ev.get('raw', {}))
             for ev in events if publisher_utils.verify_signature(
-                ev, cfg.CONF.publisher.telemetry_secret)
+                ev, self.conf.publisher.telemetry_secret)
         ]
         try:
             with self.publish_context as p:
                 p(events)
         except Exception:
-            if not cfg.CONF.notification.ack_on_event_error:
+            if not self.conf.notification.ack_on_event_error:
                 return oslo_messaging.NotificationResult.REQUEUE
             raise
         return oslo_messaging.NotificationResult.HANDLED
 
 
 class _PipelineTransportManager(object):
-    def __init__(self):
+    def __init__(self, conf):
+        self.conf = conf
         self.transporters = []
 
     @staticmethod
@@ -189,24 +196,21 @@ class SamplePipelineTransportManager(_PipelineTransportManager):
     filter_attr = 'counter_name'
     event_type = 'ceilometer.pipeline'
 
-    @staticmethod
-    def serializer(data):
+    def serializer(self, data):
         return publisher_utils.meter_message_from_counter(
-            data, cfg.CONF.publisher.telemetry_secret)
+            data, self.conf.publisher.telemetry_secret)
 
 
 class EventPipelineTransportManager(_PipelineTransportManager):
     filter_attr = 'event_type'
     event_type = 'pipeline.event'
 
-    @staticmethod
-    def serializer(data):
+    def serializer(self, data):
         return publisher_utils.message_from_event(
-            data, cfg.CONF.publisher.telemetry_secret)
+            data, self.conf.publisher.telemetry_secret)
 
 
 class PublishContext(object):
-
     def __init__(self, pipelines=None):
         pipelines = pipelines or []
         self.pipelines = set(pipelines)
@@ -226,14 +230,12 @@ class PublishContext(object):
 
 
 class Source(object):
-    """Represents a source of samples or events."""
+    """Represents a generic source"""
 
     def __init__(self, cfg):
         self.cfg = cfg
-
         try:
             self.name = cfg['name']
-            self.sinks = cfg.get('sinks')
         except KeyError as err:
             raise PipelineException(
                 "Required field %s not specified" % err.args[0], cfg)
@@ -241,17 +243,6 @@ class Source(object):
     def __str__(self):
         return self.name
 
-    def check_sinks(self, sinks):
-        if not self.sinks:
-            raise PipelineException(
-                "No sink defined in source %s" % self,
-                self.cfg)
-        for sink in self.sinks:
-            if sink not in sinks:
-                raise PipelineException(
-                    "Dangling sink %s from source %s" % (sink, self),
-                    self.cfg)
-
     def check_source_filtering(self, data, d_type):
         """Source data rules checking
 
@@ -289,7 +280,30 @@ class Source(object):
         return all(datapoint.startswith('!') for datapoint in dataset)
 
 
-class EventSource(Source):
+class PipelineSource(Source):
+    """Represents a source of samples or events."""
+
+    def __init__(self, cfg):
+        super(PipelineSource, self).__init__(cfg)
+        try:
+            self.sinks = cfg['sinks']
+        except KeyError as err:
+            raise PipelineException(
+                "Required field %s not specified" % err.args[0], cfg)
+
+    def check_sinks(self, sinks):
+        if not self.sinks:
+            raise PipelineException(
+                "No sink defined in source %s" % self,
+                self.cfg)
+        for sink in self.sinks:
+            if sink not in sinks:
+                raise PipelineException(
+                    "Dangling sink %s from source %s" % (sink, self),
+                    self.cfg)
+
+
+class EventSource(PipelineSource):
     """Represents a source of events.
 
     In effect it is a set of notification handlers capturing events for a set
@@ -305,23 +319,47 @@ class EventSource(Source):
         return self.is_supported(self.events, event_name)
 
 
-class SampleSource(Source):
+class SampleSource(PipelineSource):
     """Represents a source of samples.
 
-    In effect it is a set of pollsters and/or notification handlers emitting
+    In effect it is a set of notification handlers processing
     samples for a set of matching meters. Each source encapsulates meter name
-    matching, polling interval determination, optional resource enumeration or
-    discovery, and mapping to one or more sinks for publication.
+    matching and mapping to one or more sinks for publication.
     """
 
     def __init__(self, cfg):
         super(SampleSource, self).__init__(cfg)
-        # Support 'counters' for backward compatibility
-        self.meters = cfg.get('meters', cfg.get('counters'))
         try:
-            self.interval = int(cfg.get('interval', 600))
+            self.meters = cfg['meters']
+        except KeyError:
+            raise PipelineException("Missing meters value", cfg)
+        self.check_source_filtering(self.meters, 'meters')
+
+    def support_meter(self, meter_name):
+        return self.is_supported(self.meters, meter_name)
+
+
+class PollingSource(Source):
+    """Represents a source of pollsters
+
+    In effect it is a set of pollsters emitting
+    samples for a set of matching meters. Each source encapsulates meter name
+    matching, polling interval determination, optional resource enumeration or
+    discovery.
+    """
+
+    def __init__(self, cfg):
+        super(PollingSource, self).__init__(cfg)
+        try:
+            self.meters = cfg['meters']
+        except KeyError:
+            raise PipelineException("Missing meters value", cfg)
+        try:
+            self.interval = int(cfg['interval'])
         except ValueError:
             raise PipelineException("Invalid interval value", cfg)
+        except KeyError:
+            raise PipelineException("Missing interval value", cfg)
         if self.interval <= 0:
             raise PipelineException("Interval value should > 0", cfg)
 
@@ -366,7 +404,8 @@ class Sink(object):
     passed data directly from the sink which are published unchanged.
     """
 
-    def __init__(self, cfg, transformer_manager):
+    def __init__(self, conf, cfg, transformer_manager, publisher_manager):
+        self.conf = conf
         self.cfg = cfg
 
         try:
@@ -385,11 +424,12 @@ class Sink(object):
             if '://' not in p:
                 # Support old format without URL
                 p = p + "://"
+
             try:
-                self.publishers.append(publisher.get_publisher(p,
-                                                               self.NAMESPACE))
+                self.publishers.append(publisher_manager.get(p))
             except Exception:
-                LOG.exception(_("Unable to load publisher %s"), p)
+                LOG.error(_LE("Unable to load publisher %s"), p,
+                          exc_info=True)
 
         self.multi_publish = True if len(self.publishers) > 1 else False
         self.transformers = self._setup_transformers(cfg, transformer_manager)
@@ -419,7 +459,7 @@ class Sink(object):
 
 class EventSink(Sink):
 
-    NAMESPACE = 'ceilometer.event.publisher'
+    PUBLISHER_PURPOSE = 'event'
 
     def publish_events(self, events):
         if events:
@@ -427,11 +467,12 @@ class EventSink(Sink):
                 try:
                     p.publish_events(events)
                 except Exception:
-                    LOG.exception(_("Pipeline %(pipeline)s: %(status)s"
-                                    " after error from publisher %(pub)s") %
-                                   ({'pipeline': self, 'status': 'Continue' if
-                                     self.multi_publish else 'Exit', 'pub': p}
-                                    ))
+                    LOG.error(_LE("Pipeline %(pipeline)s: %(status)s "
+                                  "after error from publisher %(pub)s") %
+                              {'pipeline': self,
+                               'status': 'Continue' if
+                               self.multi_publish else 'Exit', 'pub': p},
+                              exc_info=True)
                     if not self.multi_publish:
                         raise
 
@@ -442,7 +483,7 @@ class EventSink(Sink):
 
 class SampleSink(Sink):
 
-    NAMESPACE = 'ceilometer.publisher'
+    PUBLISHER_PURPOSE = 'sample'
 
     def _transform_sample(self, start, sample):
         try:
@@ -455,14 +496,13 @@ class SampleSink(Sink):
                                                   'trans': transformer})
                     return
             return sample
-        except Exception as err:
-            # TODO(gordc): only use one log level.
-            LOG.warning(_("Pipeline %(pipeline)s: "
-                          "Exit after error from transformer "
-                          "%(trans)s for %(smp)s") % ({'pipeline': self,
-                                                       'trans': transformer,
-                                                       'smp': sample}))
-            LOG.exception(err)
+        except Exception:
+            LOG.error(_LE("Pipeline %(pipeline)s: Exit after error "
+                          "from transformer %(trans)s "
+                          "for %(smp)s") % {'pipeline': self,
+                                            'trans': transformer,
+                                            'smp': sample},
+                      exc_info=True)
 
     def _publish_samples(self, start, samples):
         """Push samples into pipeline for publishing.
@@ -493,10 +533,10 @@ class SampleSink(Sink):
                 try:
                     p.publish_samples(transformed_samples)
                 except Exception:
-                    LOG.exception(_(
-                        "Pipeline %(pipeline)s: Continue after error "
-                        "from publisher %(pub)s") % ({'pipeline': self,
-                                                      'pub': p}))
+                    LOG.error(_LE("Pipeline %(pipeline)s: Continue after "
+                                  "error from publisher %(pub)s")
+                              % {'pipeline': self, 'pub': p},
+                              exc_info=True)
 
     def publish_samples(self, samples):
         self._publish_samples(0, samples)
@@ -508,19 +548,19 @@ class SampleSink(Sink):
             try:
                 self._publish_samples(i + 1,
                                       list(transformer.flush()))
-            except Exception as err:
-                LOG.warning(_(
-                    "Pipeline %(pipeline)s: Error flushing "
-                    "transformer %(trans)s") % ({'pipeline': self,
-                                                 'trans': transformer}))
-                LOG.exception(err)
+            except Exception:
+                LOG.error(_LE("Pipeline %(pipeline)s: Error "
+                              "flushing transformer %(trans)s")
+                          % {'pipeline': self, 'trans': transformer},
+                          exc_info=True)
 
 
 @six.add_metaclass(abc.ABCMeta)
 class Pipeline(object):
     """Represents a coupling between a sink and a corresponding source."""
 
-    def __init__(self, source, sink):
+    def __init__(self, conf, source, sink):
+        self.conf = conf
         self.source = source
         self.sink = sink
         self.name = str(self)
@@ -563,17 +603,6 @@ class EventPipeline(Pipeline):
 class SamplePipeline(Pipeline):
     """Represents a pipeline for Samples."""
 
-    def get_interval(self):
-        return self.source.interval
-
-    @property
-    def resources(self):
-        return self.source.resources
-
-    @property
-    def discovery(self):
-        return self.source.discovery
-
     def support_meter(self, meter_name):
         return self.source.support_meter(meter_name)
 
@@ -614,11 +643,13 @@ class SamplePipeline(Pipeline):
         self.sink.publish_samples(supported)
 
 
-SAMPLE_TYPE = {'pipeline': SamplePipeline,
+SAMPLE_TYPE = {'name': 'sample',
+               'pipeline': SamplePipeline,
                'source': SampleSource,
                'sink': SampleSink}
 
-EVENT_TYPE = {'pipeline': EventPipeline,
+EVENT_TYPE = {'name': 'event',
+              'pipeline': EventPipeline,
               'source': EventSource,
               'sink': EventSink}
 
@@ -626,23 +657,21 @@ EVENT_TYPE = {'pipeline': EventPipeline,
 class ConfigManagerBase(object):
     """Base class for managing configuration file refresh"""
 
-    def __init__(self):
+    def __init__(self, conf):
+        self.conf = conf
         self.cfg_loc = None
 
-    def load_config(self, cfg_info):
+    def load_config(self, cfg_file):
         """Load a configuration file and set its refresh values."""
-        if isinstance(cfg_info, dict):
-            conf = cfg_info
+        if os.path.exists(cfg_file):
+            self.cfg_loc = cfg_file
         else:
-            if not os.path.exists(cfg_info):
-                cfg_info = cfg.CONF.find_file(cfg_info)
-            with open(cfg_info) as fap:
-                data = fap.read()
-
-            conf = yaml.safe_load(data)
-            self.cfg_loc = cfg_info
-            self.cfg_mtime = self.get_cfg_mtime()
-            self.cfg_hash = self.get_cfg_hash()
+            self.cfg_loc = self.conf.find_file(cfg_file)
+        with open(self.cfg_loc) as fap:
+            data = fap.read()
+        conf = yaml.safe_load(data)
+        self.cfg_mtime = self.get_cfg_mtime()
+        self.cfg_hash = self.get_cfg_hash()
         LOG.info("Config file: %s", conf)
         return conf
 
@@ -676,23 +705,36 @@ class ConfigManagerBase(object):
         return False
 
 
+class PublisherManager(object):
+    def __init__(self, conf, purpose):
+        self._loaded_publishers = {}
+        self._conf = conf
+        self._purpose = purpose
+
+    def get(self, url):
+        if url not in self._loaded_publishers:
+            p = publisher.get_publisher(
+                self._conf, url,
+                'ceilometer.%s.publisher' % self._purpose)
+            self._loaded_publishers[url] = p
+        return self._loaded_publishers[url]
+
+
 class PipelineManager(ConfigManagerBase):
     """Pipeline Manager
 
     Pipeline manager sets up pipelines according to config file
-
-    Usually only one pipeline manager exists in the system.
-
     """
 
-    def __init__(self, cfg_info, transformer_manager, p_type=SAMPLE_TYPE):
+    def __init__(self, conf, cfg_file, transformer_manager,
+                 p_type=SAMPLE_TYPE):
         """Setup the pipelines according to config.
 
         The configuration is supported as follows:
 
         Decoupled: the source and sink configuration are separately
         specified before being linked together. This allows source-
-        specific configuration, such as resource discovery, to be
+        specific configuration, such as meter handling, to be
         kept focused only on the fine-grained source while avoiding
         the necessity for wide duplication of sink-related config.
 
@@ -700,13 +742,10 @@ class PipelineManager(ConfigManagerBase):
         of dictionaries defining sources and sinks, for example:
 
         {"sources": [{"name": source_1,
-                      "interval": interval_time,
                       "meters" : ["meter_1", "meter_2"],
-                      "resources": ["resource_uri1", "resource_uri2"],
                       "sinks" : ["sink_1", "sink_2"]
                      },
                      {"name": source_2,
-                      "interval": interval_time,
                       "meters" : ["meter_3"],
                       "sinks" : ["sink_2"]
                      },
@@ -727,38 +766,28 @@ class PipelineManager(ConfigManagerBase):
                    ]
         }
 
-        The interval determines the cadence of sample injection into
-        the pipeline where samples are produced under the direct control
-        of an agent, i.e. via a polling cycle as opposed to incoming
-        notifications.
-
         Valid meter format is '*', '!meter_name', or 'meter_name'.
         '*' is wildcard symbol means any meters; '!meter_name' means
         "meter_name" will be excluded; 'meter_name' means 'meter_name'
         will be included.
 
-        The 'meter_name" is Sample name field.
-
         Valid meters definition is all "included meter names", all
         "excluded meter names", wildcard and "excluded meter names", or
         only wildcard.
 
-        The resources is list of URI indicating the resources from where
-        the meters should be polled. It's optional and it's up to the
-        specific pollster to decide how to use it.
-
         Transformer's name is plugin name in setup.cfg.
 
         Publisher's name is plugin name in setup.cfg
 
         """
-        super(PipelineManager, self).__init__()
-        cfg = self.load_config(cfg_info)
+        super(PipelineManager, self).__init__(conf)
+        cfg = self.load_config(cfg_file)
         self.pipelines = []
         if not ('sources' in cfg and 'sinks' in cfg):
             raise PipelineException("Both sources & sinks are required",
                                     cfg)
         LOG.info(_LI('detected decoupled pipeline config format'))
+        publisher_manager = PublisherManager(self.conf, p_type['name'])
 
         unique_names = set()
         sources = []
@@ -780,13 +809,15 @@ class PipelineManager(ConfigManagerBase):
                                         name, self)
             else:
                 unique_names.add(name)
-                sinks[s['name']] = p_type['sink'](s, transformer_manager)
+                sinks[s['name']] = p_type['sink'](self.conf, s,
+                                                  transformer_manager,
+                                                  publisher_manager)
         unique_names.clear()
 
         for source in sources:
             source.check_sinks(sinks)
             for target in source.sinks:
-                pipe = p_type['pipeline'](source, sinks[target])
+                pipe = p_type['pipeline'](self.conf, source, sinks[target])
                 if pipe.name in unique_names:
                     raise PipelineException(
                         "Duplicate pipeline name: %s. Ensure pipeline"
@@ -811,51 +842,73 @@ class PollingManager(ConfigManagerBase):
     Polling manager sets up polling according to config file.
     """
 
-    def __init__(self, cfg_info):
+    def __init__(self, conf, cfg_file):
         """Setup the polling according to config.
 
-        The configuration is the sources half of the Pipeline Config.
+        The configuration is supported as follows:
+
+        {"sources": [{"name": source_1,
+                      "interval": interval_time,
+                      "meters" : ["meter_1", "meter_2"],
+                      "resources": ["resource_uri1", "resource_uri2"],
+                     },
+                     {"name": source_2,
+                      "interval": interval_time,
+                      "meters" : ["meter_3"],
+                     },
+                    ]}
+        }
+
+        The interval determines the cadence of sample polling
+
+        Valid meter format is '*', '!meter_name', or 'meter_name'.
+        '*' is wildcard symbol means any meters; '!meter_name' means
+        "meter_name" will be excluded; 'meter_name' means 'meter_name'
+        will be included.
+
+        Valid meters definition is all "included meter names", all
+        "excluded meter names", wildcard and "excluded meter names", or
+        only wildcard.
+
+        The resources is list of URI indicating the resources from where
+        the meters should be polled. It's optional and it's up to the
+        specific pollster to decide how to use it.
+
         """
-        super(PollingManager, self).__init__()
-        cfg = self.load_config(cfg_info)
+        super(PollingManager, self).__init__(conf)
+        try:
+            cfg = self.load_config(cfg_file)
+        except (TypeError, IOError):
+            LOG.warning(_LW('Unable to locate polling configuration, falling '
+                            'back to pipeline configuration.'))
+            cfg = self.load_config(conf.pipeline_cfg_file)
         self.sources = []
-        if not ('sources' in cfg and 'sinks' in cfg):
-            raise PipelineException("Both sources & sinks are required",
-                                    cfg)
-        LOG.info(_LI('detected decoupled pipeline config format'))
-
-        unique_names = set()
+        if 'sources' not in cfg:
+            raise PollingException("sources required", cfg)
         for s in cfg.get('sources'):
-            name = s.get('name')
-            if name in unique_names:
-                raise PipelineException("Duplicated source names: %s" %
-                                        name, self)
-            else:
-                unique_names.add(name)
-                self.sources.append(SampleSource(s))
-        unique_names.clear()
+            self.sources.append(PollingSource(s))
 
 
-def setup_event_pipeline(transformer_manager=None):
+def setup_event_pipeline(conf, transformer_manager=None):
     """Setup event pipeline manager according to yaml config file."""
     default = extension.ExtensionManager('ceilometer.transformer')
-    cfg_file = cfg.CONF.event_pipeline_cfg_file
-    return PipelineManager(cfg_file, transformer_manager or default,
+    cfg_file = conf.event_pipeline_cfg_file
+    return PipelineManager(conf, cfg_file, transformer_manager or default,
                            EVENT_TYPE)
 
 
-def setup_pipeline(transformer_manager=None):
+def setup_pipeline(conf, transformer_manager=None):
     """Setup pipeline manager according to yaml config file."""
     default = extension.ExtensionManager('ceilometer.transformer')
-    cfg_file = cfg.CONF.pipeline_cfg_file
-    return PipelineManager(cfg_file, transformer_manager or default,
+    cfg_file = conf.pipeline_cfg_file
+    return PipelineManager(conf, cfg_file, transformer_manager or default,
                            SAMPLE_TYPE)
 
 
-def setup_polling():
+def setup_polling(conf):
     """Setup polling manager according to yaml config file."""
-    cfg_file = cfg.CONF.pipeline_cfg_file
-    return PollingManager(cfg_file)
+    cfg_file = conf.polling.cfg_file
+    return PollingManager(conf, cfg_file)
 
 
 def get_pipeline_grouping_key(pipe):
