@@ -62,8 +62,8 @@ class KafkaBrokerPublisher(messaging.MessagingPublisher):
     field. If max_retry is not specified, default the number of retry is 100.
     """
 
-    def __init__(self, parsed_url):
-        super(KafkaBrokerPublisher, self).__init__(parsed_url)
+    def __init__(self, conf, parsed_url):
+        super(KafkaBrokerPublisher, self).__init__(conf, parsed_url)
         options = urlparse.parse_qs(parsed_url.query)
 
         self._producer = None
@@ -77,20 +77,24 @@ class KafkaBrokerPublisher(messaging.MessagingPublisher):
             return
 
         try:
-            client = kafka.KafkaClient("%s:%s" % (self._host, self._port))
-            self._producer = kafka.SimpleProducer(client)
+            self._producer = kafka.KafkaProducer(
+                bootstrap_servers=["%s:%s" % (self._host, self._port)])
+        except kafka.errors.KafkaError as e:
+            LOG.exception(_LE("Failed to connect to Kafka service: %s"), e)
+            raise messaging.DeliveryFailure('Kafka Client is not available, '
+                                            'please restart Kafka client')
         except Exception as e:
             LOG.exception(_LE("Failed to connect to Kafka service: %s"), e)
             raise messaging.DeliveryFailure('Kafka Client is not available, '
                                             'please restart Kafka client')
 
-    def _send(self, context, event_type, data):
+    def _send(self, event_type, data):
         self._ensure_connection()
         # TODO(sileht): don't split the payload into multiple network
         # message ... but how to do that without breaking consuming
         # application...
         try:
             for d in data:
-                self._producer.send_messages(self._topic, jsonutils.dumps(d))
+                self._producer.send(self._topic, jsonutils.dumps(d))
         except Exception as e:
             messaging.raise_delivery_failure(e)
