@@ -19,6 +19,7 @@ import hashlib
 import hmac
 
 from oslo_config import cfg
+from oslo_utils import secretutils
 import six
 
 from ceilometer import utils
@@ -37,7 +38,6 @@ OPTS = [
                                                   "publisher")]
                ),
 ]
-cfg.CONF.register_opts(OPTS, group="publisher")
 
 
 def compute_signature(message, secret):
@@ -58,36 +58,6 @@ def compute_signature(message, secret):
     return digest_maker.hexdigest()
 
 
-def besteffort_compare_digest(first, second):
-    """Returns True if both string inputs are equal, otherwise False.
-
-    This function should take a constant amount of time regardless of
-    how many characters in the strings match.
-
-    """
-    # NOTE(sileht): compare_digest method protected for timing-attacks
-    # exists since python >= 2.7.7 and python >= 3.3
-    # this a bit less-secure python fallback version
-    # taken from https://github.com/openstack/python-keystoneclient/blob/
-    # master/keystoneclient/middleware/memcache_crypt.py#L88
-    if len(first) != len(second):
-        return False
-    result = 0
-    if six.PY3 and isinstance(first, bytes) and isinstance(second, bytes):
-        for x, y in zip(first, second):
-            result |= x ^ y
-    else:
-        for x, y in zip(first, second):
-            result |= ord(x) ^ ord(y)
-    return result == 0
-
-
-if hasattr(hmac, 'compare_digest'):
-    compare_digest = hmac.compare_digest
-else:
-    compare_digest = besteffort_compare_digest
-
-
 def verify_signature(message, secret):
     """Check the signature in the message.
 
@@ -108,7 +78,7 @@ def verify_signature(message, secret):
     if six.PY3:
         new_sig = new_sig.encode('ascii')
 
-    return compare_digest(new_sig, old_sig)
+    return secretutils.constant_time_compare(new_sig, old_sig)
 
 
 def meter_message_from_counter(sample, secret):
@@ -128,7 +98,6 @@ def meter_message_from_counter(sample, secret):
            'timestamp': sample.timestamp,
            'resource_metadata': sample.resource_metadata,
            'message_id': sample.id,
-           'monotonic_time': sample.monotonic_time,
            }
     msg['message_signature'] = compute_signature(msg, secret)
     return msg
