@@ -16,7 +16,6 @@
 import abc
 
 import cotyledon
-from oslo_config import cfg
 from oslo_log import log
 import six
 
@@ -29,9 +28,9 @@ LOG = log.getLogger(__name__)
 
 @six.add_metaclass(abc.ABCMeta)
 class PipelineBasedService(cotyledon.Service):
-    def __init__(self, worker_id):
+    def __init__(self, worker_id, conf):
         super(PipelineBasedService, self).__init__(worker_id)
-        self.refresh_pipeline_periodic = None
+        self.conf = conf
 
     def clear_pipeline_validation_status(self):
         """Clears pipeline validation status flags."""
@@ -42,11 +41,12 @@ class PipelineBasedService(cotyledon.Service):
         """Initializes pipeline refresh state."""
         self.clear_pipeline_validation_status()
 
-        if (cfg.CONF.refresh_pipeline_cfg or
-                cfg.CONF.refresh_event_pipeline_cfg):
+        self.refresh_pipeline_periodic = None
+        if (self.conf.refresh_pipeline_cfg or
+                self.conf.refresh_event_pipeline_cfg):
             self.refresh_pipeline_periodic = utils.create_periodic(
                 target=self.refresh_pipeline,
-                spacing=cfg.CONF.pipeline_polling_interval)
+                spacing=self.conf.pipeline_polling_interval)
             utils.spawn_thread(self.refresh_pipeline_periodic.start)
 
     def terminate(self):
@@ -61,7 +61,7 @@ class PipelineBasedService(cotyledon.Service):
     def refresh_pipeline(self):
         """Refreshes appropriate pipeline, then delegates to agent."""
 
-        if cfg.CONF.refresh_pipeline_cfg:
+        if self.conf.refresh_pipeline_cfg:
             manager = None
             if hasattr(self, 'pipeline_manager'):
                 manager = self.pipeline_manager
@@ -76,16 +76,18 @@ class PipelineBasedService(cotyledon.Service):
                                'new': pipeline_hash})
                     # Pipeline in the notification agent.
                     if hasattr(self, 'pipeline_manager'):
-                        self.pipeline_manager = pipeline.setup_pipeline()
+                        self.pipeline_manager = pipeline.setup_pipeline(
+                            self.conf)
                     # Polling in the polling agent.
                     elif hasattr(self, 'polling_manager'):
-                        self.polling_manager = pipeline.setup_polling()
+                        self.polling_manager = pipeline.setup_polling(
+                            self.conf)
                     self.pipeline_validated = True
                 except Exception as err:
                     LOG.exception(_LE('Unable to load changed pipeline: %s')
                                   % err)
 
-        if cfg.CONF.refresh_event_pipeline_cfg:
+        if self.conf.refresh_event_pipeline_cfg:
             # Pipeline in the notification agent.
             manager = (self.event_pipeline_manager
                        if hasattr(self, 'event_pipeline_manager') else None)
@@ -96,8 +98,8 @@ class PipelineBasedService(cotyledon.Service):
                               "old hash: %(old)s, new hash: %(new)s",
                               {'old': manager.cfg_hash,
                                'new': ev_pipeline_hash})
-                    self.event_pipeline_manager = (pipeline.
-                                                   setup_event_pipeline())
+                    self.event_pipeline_manager = (
+                        pipeline. setup_event_pipeline(self.conf))
                     self.event_pipeline_validated = True
                 except Exception as err:
                     LOG.exception(_LE('Unable to load changed event pipeline:'
