@@ -116,9 +116,6 @@ class Connection(hbase_base.Connection, base.Connection):
     RESOURCE_TABLE = "resource"
     METER_TABLE = "meter"
 
-    def __init__(self, url):
-        super(Connection, self).__init__(url)
-
     def upgrade(self):
         tables = [self.RESOURCE_TABLE, self.METER_TABLE]
         column_families = {'f': dict(max_versions=1)}
@@ -146,10 +143,6 @@ class Connection(hbase_base.Connection, base.Connection):
         :param data: a dictionary such as returned by
           ceilometer.publisher.utils.meter_message_from_counter
         """
-
-        # We must not record thing.
-        data.pop("monotonic_time", None)
-
         with self.conn_pool.connection() as conn:
             resource_table = conn.table(self.RESOURCE_TABLE)
             meter_table = conn.table(self.METER_TABLE)
