@@ -28,6 +28,7 @@ from six.moves.urllib import parse as urlparse
 import sqlalchemy
 from testtools import testcase
 
+from ceilometer import service
 from ceilometer import storage
 from ceilometer.tests import base as test_base
 try:
@@ -36,10 +37,13 @@ except ImportError:
     mocks = None   # happybase module is not Python 3 compatible yet
 
 
-class MongoDbManager(fixtures.Fixture):
-
-    def __init__(self, url):
+class DBManager(fixtures.Fixture):
+    def __init__(self, conf, url):
         self._url = url
+        self._conf = conf
+
+
+class MongoDbManager(DBManager):
 
     def setUp(self):
         super(MongoDbManager, self).setUp()
@@ -48,10 +52,7 @@ class MongoDbManager(fixtures.Fixture):
                 action='ignore',
                 message='.*you must provide a username and password.*')
             try:
-                self.connection = storage.get_connection(
-                    self.url, 'ceilometer.metering.storage')
-                self.event_connection = storage.get_connection(
-                    self.url, 'ceilometer.event.storage')
+                self.connection = storage.get_connection(self._conf, self.url)
             except storage.StorageBadVersion as e:
                 raise testcase.TestSkipped(six.text_type(e))
 
@@ -63,8 +64,9 @@ class MongoDbManager(fixtures.Fixture):
         }
 
 
-class SQLManager(fixtures.Fixture):
-    def __init__(self, url):
+class SQLManager(DBManager):
+    def __init__(self, conf, url):
+        super(SQLManager, self).__init__(conf, url)
         db_name = 'ceilometer_%s' % uuid.uuid4().hex
         engine = sqlalchemy.create_engine(url)
         conn = engine.connect()
@@ -77,10 +79,7 @@ class SQLManager(fixtures.Fixture):
 
     def setUp(self):
         super(SQLManager, self).setUp()
-        self.connection = storage.get_connection(
-            self.url, 'ceilometer.metering.storage')
-        self.event_connection = storage.get_connection(
-            self.url, 'ceilometer.event.storage')
+        self.connection = storage.get_connection(self._conf, self.url)
 
 
 class PgSQLManager(SQLManager):
@@ -97,32 +96,10 @@ class MySQLManager(SQLManager):
         conn.execute('CREATE DATABASE %s;' % db_name)
 
 
-class ElasticSearchManager(fixtures.Fixture):
-    def __init__(self, url):
-        self.url = url
-
-    def setUp(self):
-        super(ElasticSearchManager, self).setUp()
-        self.connection = storage.get_connection(
-            'sqlite://', 'ceilometer.metering.storage')
-        self.event_connection = storage.get_connection(
-            self.url, 'ceilometer.event.storage')
-        # prefix each test with unique index name
-        self.event_connection.index_name = 'events_%s' % uuid.uuid4().hex
-        # force index on write so data is queryable right away
-        self.event_connection._refresh_on_write = True
-
-
-class HBaseManager(fixtures.Fixture):
-    def __init__(self, url):
-        self._url = url
-
+class HBaseManager(DBManager):
     def setUp(self):
         super(HBaseManager, self).setUp()
-        self.connection = storage.get_connection(
-            self.url, 'ceilometer.metering.storage')
-        self.event_connection = storage.get_connection(
-            self.url, 'ceilometer.event.storage')
+        self.connection = storage.get_connection(self._conf, self.url)
         # Unique prefix for each test to keep data is distinguished because
         # all test data is stored in one table
         data_prefix = str(uuid.uuid4().hex)
@@ -152,17 +129,11 @@ class HBaseManager(fixtures.Fixture):
         )
 
 
-class SQLiteManager(fixtures.Fixture):
-
-    def __init__(self, url):
-        self.url = url
-
+class SQLiteManager(DBManager):
     def setUp(self):
         super(SQLiteManager, self).setUp()
-        self.connection = storage.get_connection(
-            self.url, 'ceilometer.metering.storage')
-        self.event_connection = storage.get_connection(
-            self.url, 'ceilometer.event.storage')
+        self.url = self._url
+        self.connection = storage.get_connection(self._conf, self._url)
 
 
 @six.add_metaclass(test_base.SkipNotImplementedMeta)
@@ -172,16 +143,14 @@ class TestBase(test_base.BaseTestCase):
         'mongodb': MongoDbManager,
         'mysql': MySQLManager,
         'postgresql': PgSQLManager,
-        'db2': MongoDbManager,
         'sqlite': SQLiteManager,
-        'es': ElasticSearchManager,
     }
     if mocks is not None:
         DRIVER_MANAGERS['hbase'] = HBaseManager
 
     def setUp(self):
         super(TestBase, self).setUp()
-        db_url = os.environ.get('OVERTEST_URL', "sqlite://").replace(
+        db_url = os.environ.get('PIFPAF_URL', "sqlite://").replace(
             "mysql://", "mysql+pymysql://")
 
         engine = urlparse.urlparse(db_url).scheme
@@ -196,23 +165,20 @@ class TestBase(test_base.BaseTestCase):
             raise testcase.TestSkipped(
                 'Test is not applicable for %s' % engine)
 
-        self.CONF = self.useFixture(fixture_config.Config()).conf
-        self.CONF([], project='ceilometer', validate_default_values=True)
+        conf = service.prepare_service([], [])
+        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
 
         manager = self.DRIVER_MANAGERS.get(engine)
         if not manager:
             self.skipTest("missing driver manager: %s" % engine)
 
-        self.db_manager = manager(db_url)
+        self.db_manager = manager(self.CONF, db_url)
 
         self.useFixture(self.db_manager)
 
         self.conn = self.db_manager.connection
         self.conn.upgrade()
 
-        self.event_conn = self.db_manager.event_connection
-        self.event_conn.upgrade()
-
         self.useFixture(mockpatch.Patch('ceilometer.storage.get_connection',
                                         side_effect=self._get_connection))
 
@@ -226,15 +192,11 @@ class TestBase(test_base.BaseTestCase):
         )
 
     def tearDown(self):
-        self.event_conn.clear()
-        self.event_conn = None
         self.conn.clear()
         self.conn = None
         super(TestBase, self).tearDown()
 
-    def _get_connection(self, url, namespace):
-        if namespace == "ceilometer.event.storage":
-            return self.event_conn
+    def _get_connection(self, conf, url):
         return self.conn
 
 
