@@ -24,14 +24,14 @@ import uuid
 from gabbi import fixture
 from oslo_config import cfg
 from oslo_config import fixture as fixture_config
-from oslo_policy import opts
 from oslo_utils import fileutils
 import six
 from six.moves.urllib import parse as urlparse
 
-from ceilometer.event.storage import models
+from ceilometer.api import app
 from ceilometer.publisher import utils
 from ceilometer import sample
+from ceilometer import service
 from ceilometer import storage
 
 # TODO(chdent): For now only MongoDB is supported, because of easy
@@ -39,6 +39,17 @@ from ceilometer import storage
 # data store.
 ENGINES = ['mongodb']
 
+# NOTE(chdent): Hack to restore semblance of global configuration to
+# pass to the WSGI app used per test suite. LOAD_APP_KWARGS are the olso
+# configuration, and the pecan application configuration of
+# which the critical part is a reference to the current indexer.
+LOAD_APP_KWARGS = None
+
+
+def setup_app():
+    global LOAD_APP_KWARGS
+    return app.load_app(**LOAD_APP_KWARGS)
+
 
 class ConfigFixture(fixture.GabbiFixture):
     """Establish the relevant configuration for a test run."""
@@ -46,6 +57,8 @@ class ConfigFixture(fixture.GabbiFixture):
     def start_fixture(self):
         """Set up config."""
 
+        global LOAD_APP_KWARGS
+
         self.conf = None
 
         # Determine the database connection.
@@ -58,11 +71,9 @@ class ConfigFixture(fixture.GabbiFixture):
         if engine not in ENGINES:
             raise case.SkipTest('Database engine not supported')
 
-        conf = fixture_config.Config().conf
+        conf = service.prepare_service([], [])
+        conf = fixture_config.Config(conf).conf
         self.conf = conf
-        self.conf([], project='ceilometer', validate_default_values=True)
-        opts.set_defaults(self.conf)
-        conf.import_group('api', 'ceilometer.api.controllers.v2.root')
 
         content = ('{"default": ""}')
         if six.PY3:
@@ -86,13 +97,15 @@ class ConfigFixture(fixture.GabbiFixture):
         database_name = '%s-%s' % (db_url, str(uuid.uuid4()))
         conf.set_override('connection', database_name, group='database')
         conf.set_override('metering_connection', '', group='database')
-        conf.set_override('event_connection', '', group='database')
 
-        conf.set_override('pecan_debug', True, group='api')
         conf.set_override('gnocchi_is_enabled', False, group='api')
         conf.set_override('aodh_is_enabled', False, group='api')
         conf.set_override('panko_is_enabled', False, group='api')
 
+        LOAD_APP_KWARGS = {
+            'conf': conf,
+        }
+
     def stop_fixture(self):
         """Reset the config and remove data."""
         if self.conf:
@@ -105,7 +118,8 @@ class SampleDataFixture(fixture.GabbiFixture):
 
     def start_fixture(self):
         """Create some samples."""
-        conf = fixture_config.Config().conf
+        global LOAD_APP_KWARGS
+        conf = LOAD_APP_KWARGS['conf']
         self.conn = storage.get_connection_from_config(conf)
         timestamp = datetime.datetime.utcnow()
         project_id = str(uuid.uuid4())
@@ -137,32 +151,6 @@ class SampleDataFixture(fixture.GabbiFixture):
         print('meter', self.conn.db.meter.remove({'source': self.source}))
 
 
-class EventDataFixture(fixture.GabbiFixture):
-    """Instantiate some sample event data for use in testing."""
-
-    def start_fixture(self):
-        """Create some events."""
-        conf = fixture_config.Config().conf
-        self.conn = storage.get_connection_from_config(conf, 'event')
-        events = []
-        name_list = ['chocolate.chip', 'peanut.butter', 'sugar']
-        for ix, name in enumerate(name_list):
-            timestamp = datetime.datetime.utcnow()
-            message_id = 'fea1b15a-1d47-4175-85a5-a4bb2c72924{}'.format(ix)
-            traits = [models.Trait('type', 1, name),
-                      models.Trait('ate', 2, ix)]
-            event = models.Event(message_id,
-                                 'cookies_{}'.format(name),
-                                 timestamp,
-                                 traits, {'nested': {'inside': 'value'}})
-            events.append(event)
-        self.conn.record_events(events)
-
-    def stop_fixture(self):
-        """Destroy the events."""
-        self.conn.db.event.remove({'event_type': '/^cookies_/'})
-
-
 class CORSConfigFixture(fixture.GabbiFixture):
     """Inject mock configuration for the CORS middleware."""
 
