@@ -26,6 +26,7 @@ from ceilometer import collector
 from ceilometer import dispatcher
 from ceilometer.publisher import utils
 from ceilometer import sample
+from ceilometer import service
 from ceilometer.tests import base as tests_base
 
 
@@ -41,7 +42,8 @@ class FakeConnection(object):
 class TestCollector(tests_base.BaseTestCase):
     def setUp(self):
         super(TestCollector, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        conf = service.prepare_service([], [])
+        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
         self.CONF.import_opt("connection", "oslo_db.options", group="database")
         self.CONF.set_override("connection", "log://", group='database')
         self.CONF.set_override('telemetry_secret', 'not-so-secret',
@@ -77,7 +79,7 @@ class TestCollector(tests_base.BaseTestCase):
             'not-so-secret')
 
         self.mock_dispatcher = self._setup_fake_dispatcher()
-        self.srv = collector.CollectorService(0)
+        self.srv = collector.CollectorService(0, self.CONF)
 
     def _setup_messaging(self, enabled=True):
         if enabled:
@@ -109,8 +111,11 @@ class TestCollector(tests_base.BaseTestCase):
 
     def _verify_udp_socket(self, udp_socket):
         conf = self.CONF.collector
-        udp_socket.setsockopt.assert_called_once_with(socket.SOL_SOCKET,
-                                                      socket.SO_REUSEADDR, 1)
+        setsocketopt_calls = [mock.call.setsockopt(socket.SOL_SOCKET,
+                                                   socket.SO_REUSEADDR, 1),
+                              mock.call.setsockopt(socket.SOL_SOCKET,
+                                                   socket.SO_REUSEPORT, 1)]
+        udp_socket.setsockopt.assert_has_calls(setsocketopt_calls)
         udp_socket.bind.assert_called_once_with((conf.udp_address,
                                                  conf.udp_port))
 
@@ -119,13 +124,15 @@ class TestCollector(tests_base.BaseTestCase):
 
         udp_socket = self._make_fake_socket(self.sample)
 
-        with mock.patch('socket.socket') as mock_socket:
-            mock_socket.return_value = udp_socket
-            self.srv.run()
-            self.addCleanup(self.srv.terminate)
-            self.srv.udp_thread.join(5)
-            self.assertFalse(self.srv.udp_thread.is_alive())
-            mock_socket.assert_called_with(socket.AF_INET, socket.SOCK_DGRAM)
+        with mock.patch('select.select', return_value=([udp_socket], [], [])):
+            with mock.patch('socket.socket') as mock_socket:
+                mock_socket.return_value = udp_socket
+                self.srv.run()
+                self.addCleanup(self.srv.terminate)
+                self.srv.udp_thread.join(5)
+                self.assertFalse(self.srv.udp_thread.is_alive())
+                mock_socket.assert_called_with(socket.AF_INET,
+                                               socket.SOCK_DGRAM)
 
         self._verify_udp_socket(udp_socket)
         mock_record = self.mock_dispatcher.record_metering_data
@@ -136,13 +143,15 @@ class TestCollector(tests_base.BaseTestCase):
         self.CONF.set_override('udp_address', '::1', group='collector')
         sock = self._make_fake_socket(self.sample)
 
-        with mock.patch.object(socket, 'socket') as mock_socket:
-            mock_socket.return_value = sock
-            self.srv.run()
-            self.addCleanup(self.srv.terminate)
-            self.srv.udp_thread.join(5)
-            self.assertFalse(self.srv.udp_thread.is_alive())
-            mock_socket.assert_called_with(socket.AF_INET6, socket.SOCK_DGRAM)
+        with mock.patch('select.select', return_value=([sock], [], [])):
+            with mock.patch.object(socket, 'socket') as mock_socket:
+                mock_socket.return_value = sock
+                self.srv.run()
+                self.addCleanup(self.srv.terminate)
+                self.srv.udp_thread.join(5)
+                self.assertFalse(self.srv.udp_thread.is_alive())
+                mock_socket.assert_called_with(socket.AF_INET6,
+                                               socket.SOCK_DGRAM)
 
     def test_udp_receive_storage_error(self):
         self._setup_messaging(False)
@@ -150,11 +159,12 @@ class TestCollector(tests_base.BaseTestCase):
         mock_record.side_effect = self._raise_error
 
         udp_socket = self._make_fake_socket(self.sample)
-        with mock.patch('socket.socket', return_value=udp_socket):
-            self.srv.run()
-            self.addCleanup(self.srv.terminate)
-            self.srv.udp_thread.join(5)
-            self.assertFalse(self.srv.udp_thread.is_alive())
+        with mock.patch('select.select', return_value=([udp_socket], [], [])):
+            with mock.patch('socket.socket', return_value=udp_socket):
+                self.srv.run()
+                self.addCleanup(self.srv.terminate)
+                self.srv.udp_thread.join(5)
+                self.assertFalse(self.srv.udp_thread.is_alive())
 
         self._verify_udp_socket(udp_socket)
 
@@ -164,17 +174,21 @@ class TestCollector(tests_base.BaseTestCase):
     def _raise_error(*args, **kwargs):
         raise Exception
 
-    def test_udp_receive_bad_decoding(self):
+    @mock.patch.object(collector, 'LOG')
+    def test_udp_receive_bad_decoding(self, log):
         self._setup_messaging(False)
         udp_socket = self._make_fake_socket(self.sample)
-        with mock.patch('socket.socket', return_value=udp_socket):
-            with mock.patch('msgpack.loads', self._raise_error):
-                self.srv.run()
-                self.addCleanup(self.srv.terminate)
-                self.srv.udp_thread.join(5)
-                self.assertFalse(self.srv.udp_thread.is_alive())
+        with mock.patch('select.select', return_value=([udp_socket], [], [])):
+            with mock.patch('socket.socket', return_value=udp_socket):
+                with mock.patch('msgpack.loads', self._raise_error):
+                    self.srv.run()
+                    self.addCleanup(self.srv.terminate)
+                    self.srv.udp_thread.join(5)
+                    self.assertFalse(self.srv.udp_thread.is_alive())
 
         self._verify_udp_socket(udp_socket)
+        log.warning.assert_called_once_with(
+            "UDP: Cannot decode data sent by %s", mock.ANY)
 
     @mock.patch.object(collector.CollectorService, 'start_udp')
     def test_only_udp(self, udp_start):
@@ -195,15 +209,16 @@ class TestCollector(tests_base.BaseTestCase):
     def test_udp_receive_valid_encoding(self):
         self._setup_messaging(False)
         self.data_sent = []
-        with mock.patch('socket.socket',
-                        return_value=self._make_fake_socket(self.utf8_msg)):
-            self.srv.run()
-            self.addCleanup(self.srv.terminate)
-            self.srv.udp_thread.join(5)
-            self.assertFalse(self.srv.udp_thread.is_alive())
-            self.assertTrue(utils.verify_signature(
-                self.mock_dispatcher.method_calls[0][1][0],
-                "not-so-secret"))
+        sock = self._make_fake_socket(self.utf8_msg)
+        with mock.patch('select.select', return_value=([sock], [], [])):
+            with mock.patch('socket.socket', return_value=sock):
+                self.srv.run()
+                self.addCleanup(self.srv.terminate)
+                self.srv.udp_thread.join(5)
+                self.assertFalse(self.srv.udp_thread.is_alive())
+                self.assertTrue(utils.verify_signature(
+                    self.mock_dispatcher.method_calls[0][1][0],
+                    "not-so-secret"))
 
     def _test_collector_requeue(self, listener, batch_listener=False):
 
