@@ -18,12 +18,10 @@ import shutil
 
 from keystoneauth1 import exceptions as ka_exceptions
 import mock
-from novaclient import client as novaclient
 from oslo_config import fixture as fixture_config
 from oslo_utils import fileutils
 from oslotest import base
 from oslotest import mockpatch
-import requests
 import six
 from stevedore import extension
 import yaml
@@ -32,6 +30,7 @@ from ceilometer.agent import manager
 from ceilometer.agent import plugin_base
 from ceilometer.hardware import discovery
 from ceilometer import pipeline
+from ceilometer import service
 from ceilometer.tests.unit.agent import agentbase
 
 
@@ -45,23 +44,23 @@ class PollingException(Exception):
 
 class TestPollsterBuilder(agentbase.TestPollster):
     @classmethod
-    def build_pollsters(cls):
-        return [('builder1', cls()), ('builder2', cls())]
+    def build_pollsters(cls, conf):
+        return [('builder1', cls(conf)), ('builder2', cls(conf))]
 
 
 class TestManager(base.BaseTestCase):
     def setUp(self):
         super(TestManager, self).setUp()
         self.conf = self.useFixture(fixture_config.Config()).conf
-        self.conf(args=[])
+        service.prepare_service([], [], self.conf)
 
     @mock.patch('ceilometer.pipeline.setup_polling', mock.MagicMock())
     def test_load_plugins(self):
-        mgr = manager.AgentManager()
+        mgr = manager.AgentManager(0, self.conf)
         self.assertIsNotNone(list(mgr.extensions))
 
     def test_load_plugins_pollster_list(self):
-        mgr = manager.AgentManager(pollster_list=['disk.*'])
+        mgr = manager.AgentManager(0, self.conf, pollster_list=['disk.*'])
         # currently we do have 26 disk-related pollsters
         self.assertEqual(26, len(list(mgr.extensions)))
 
@@ -72,7 +71,7 @@ class TestManager(base.BaseTestCase):
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
-            manager.AgentManager,
+            manager.AgentManager, 0, self.conf,
             pollster_list=['aaa'])
 
     def test_load_plugins_no_intersection(self):
@@ -84,8 +83,7 @@ class TestManager(base.BaseTestCase):
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
-            manager.AgentManager,
-            parameters)
+            manager.AgentManager, 0, self.conf, parameters)
 
     # Test plugin load behavior based on Node Manager pollsters.
     # pollster_list is just a filter, so sensor pollsters under 'ipmi'
@@ -95,7 +93,8 @@ class TestManager(base.BaseTestCase):
     @mock.patch('ceilometer.ipmi.pollsters.sensor.SensorPollster.__init__',
                 mock.Mock(return_value=None))
     def test_load_normal_plugins(self):
-        mgr = manager.AgentManager(namespaces=['ipmi'],
+        mgr = manager.AgentManager(0, self.conf,
+                                   namespaces=['ipmi'],
                                    pollster_list=['hardware.ipmi.node.*'])
         # 8 pollsters for Node Manager
         self.assertEqual(8, len(mgr.extensions))
@@ -110,7 +109,8 @@ class TestManager(base.BaseTestCase):
         # Here we additionally check that namespaces will be converted to the
         # list if param was not set as a list.
         try:
-            manager.AgentManager(namespaces='ipmi',
+            manager.AgentManager(0, self.conf,
+                                 namespaces='ipmi',
                                  pollster_list=['hardware.ipmi.node.*'])
         except manager.EmptyPollstersList:
             err_msg = 'Skip loading extension for %s'
@@ -133,8 +133,7 @@ class TestManager(base.BaseTestCase):
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
-            manager.AgentManager,
-            parameters)
+            manager.AgentManager, 0, self.conf, parameters)
 
     # Exceptions other than ExtensionLoadError are propagated
     @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
@@ -144,20 +143,21 @@ class TestManager(base.BaseTestCase):
     def test_load_exceptional_plugins(self):
         self.assertRaises(PollingException,
                           manager.AgentManager,
+                          0, self.conf,
                           ['ipmi'],
                           ['hardware.ipmi.node.*'])
 
     def test_load_plugins_pollster_list_forbidden(self):
-        manager.cfg.CONF.set_override('backend_url', 'http://',
-                                      group='coordination')
+        self.conf.set_override('backend_url', 'http://',
+                               group='coordination')
         self.assertRaises(manager.PollsterListForbidden,
                           manager.AgentManager,
+                          0, self.conf,
                           pollster_list=['disk.*'])
-        manager.cfg.CONF.reset()
 
     def test_builder(self):
         @staticmethod
-        def fake_get_ext_mgr(namespace):
+        def fake_get_ext_mgr(namespace, *args, **kwargs):
             if 'builder' in namespace:
                 return extension.ExtensionManager.make_test_instance(
                     [
@@ -173,13 +173,14 @@ class TestManager(base.BaseTestCase):
                         extension.Extension('test',
                                             None,
                                             None,
-                                            agentbase.TestPollster()),
+                                            agentbase.TestPollster(
+                                                self.conf)),
                     ]
                 )
 
         with mock.patch.object(manager.AgentManager, '_get_ext_mgr',
                                new=fake_get_ext_mgr):
-            mgr = manager.AgentManager(namespaces=['central'])
+            mgr = manager.AgentManager(0, self.conf, namespaces=['central'])
             self.assertEqual(3, len(mgr.extensions))
             for ext in mgr.extensions:
                 self.assertIn(ext.name, ['builder1', 'builder2', 'test'])
@@ -239,9 +240,8 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
             timestamp=agentbase.default_test_data.timestamp,
             resource_metadata=agentbase.default_test_data.resource_metadata)
 
-    @staticmethod
-    def create_manager():
-        return manager.AgentManager()
+    def create_manager(self):
+        return manager.AgentManager(0, self.CONF)
 
     @staticmethod
     def setup_pipeline_file(pipeline):
@@ -259,6 +259,8 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
             self.notified_samples.append(m)
 
     def setUp(self):
+        self.conf = self.useFixture(fixture_config.Config()).conf
+        service.prepare_service([], [], self.conf)
         self.notified_samples = []
         self.notifier = mock.Mock()
         self.notifier.sample.side_effect = self.fake_notifier_sample
@@ -281,11 +283,12 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         exts.extend([extension.Extension('testkeystone',
                                          None,
                                          None,
-                                         self.PollsterKeystone(), ),
+                                         self.PollsterKeystone(self.CONF), ),
                      extension.Extension('testpollingexception',
                                          None,
                                          None,
-                                         self.PollsterPollingException(), )])
+                                         self.PollsterPollingException(
+                                             self.CONF), )])
         return exts
 
     def test_get_sample_resources(self):
@@ -310,7 +313,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'transformers': [],
                 'publishers': ["test"]}]
         }
-        self.mgr.polling_manager = pipeline.PollingManager(self.pipeline_cfg)
+        self.mgr.polling_manager = pipeline.PollingManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg))
         polling_tasks = self.mgr.setup_polling_tasks()
         self.mgr.interval_task(list(polling_tasks.values())[0])
         self.assertFalse(self.PollsterKeystone.samples)
@@ -319,11 +324,6 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
     @mock.patch('ceilometer.agent.manager.LOG')
     @mock.patch('ceilometer.nova_client.LOG')
     def test_hardware_discover_fail_minimize_logs(self, novalog, baselog):
-        self.useFixture(mockpatch.PatchObject(
-            novaclient.HTTPClient,
-            'authenticate',
-            side_effect=requests.ConnectionError))
-
         class PollsterHardware(agentbase.TestPollster):
             discovery = 'tripleo_overcloud_nodes'
 
@@ -334,16 +334,16 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
             extension.Extension('testhardware',
                                 None,
                                 None,
-                                PollsterHardware(), ),
+                                PollsterHardware(self.CONF), ),
             extension.Extension('testhardware2',
                                 None,
                                 None,
-                                PollsterHardwareAnother(), )
+                                PollsterHardwareAnother(self.CONF), )
         ])
         ext = extension.Extension('tripleo_overcloud_nodes',
                                   None,
                                   None,
-                                  discovery.NodesDiscoveryTripleO())
+                                  discovery.NodesDiscoveryTripleO(self.CONF))
         self.mgr.discoveries = (extension.ExtensionManager
                                 .make_test_instance([ext]))
 
@@ -358,7 +358,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'transformers': [],
                 'publishers': ["test"]}]
         }
-        self.mgr.polling_manager = pipeline.PollingManager(self.pipeline_cfg)
+        self.mgr.polling_manager = pipeline.PollingManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg))
         polling_tasks = self.mgr.setup_polling_tasks()
         self.mgr.interval_task(list(polling_tasks.values())[0])
         self.assertEqual(1, novalog.exception.call_count)
@@ -367,19 +369,22 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
     @mock.patch('ceilometer.agent.manager.LOG')
     def test_polling_exception(self, LOG):
         source_name = 'test_pollingexception'
+        res_list = ['test://']
         self.pipeline_cfg = {
             'sources': [{
                 'name': source_name,
                 'interval': 10,
                 'meters': ['testpollingexception'],
-                'resources': ['test://'],
+                'resources': res_list,
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
                 'transformers': [],
                 'publishers': ["test"]}]
         }
-        self.mgr.polling_manager = pipeline.PollingManager(self.pipeline_cfg)
+        self.mgr.polling_manager = pipeline.PollingManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg))
         polling_task = list(self.mgr.setup_polling_tasks().values())[0]
         pollster = list(polling_task.pollster_matches[source_name])[0]
 
@@ -389,9 +394,10 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         samples = self.notified_samples
         self.assertEqual(2, len(samples))
         LOG.error.assert_called_once_with((
-            'Prevent pollster %(name)s for '
-            'polling source %(source)s anymore!')
-            % ({'name': pollster.name, 'source': source_name}))
+            'Prevent pollster %(name)s from '
+            'polling %(res_list)s on source %(source)s anymore!')
+            % ({'name': pollster.name, 'res_list': res_list,
+                'source': source_name}))
 
     def test_batching_polled_samples_false(self):
         self.CONF.set_override('batch_polled_samples', False)
@@ -420,7 +426,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'publishers': ["test"]}]
         }
 
-        self.mgr.polling_manager = pipeline.PollingManager(pipeline_cfg)
+        self.mgr.polling_manager = pipeline.PollingManager(
+            self.CONF,
+            self.cfg2file(pipeline_cfg))
         polling_task = list(self.mgr.setup_polling_tasks().values())[0]
 
         self.mgr.interval_task(polling_task)
