@@ -16,6 +16,7 @@
 import mock
 
 from ceilometer.agent import manager
+from ceilometer.agent import plugin_base
 from ceilometer.compute.pollsters import memory
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.tests.unit.compute.pollsters import base
@@ -23,15 +24,12 @@ from ceilometer.tests.unit.compute.pollsters import base
 
 class TestMemoryPollster(base.TestPollsterBase):
 
-    def setUp(self):
-        super(TestMemoryPollster, self).setUp()
-
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def test_get_samples(self):
         next_value = iter((
             virt_inspector.MemoryUsageStats(usage=1.0),
             virt_inspector.MemoryUsageStats(usage=2.0),
-            virt_inspector.NoDataException(),
+            virt_inspector.InstanceNoDataException(),
             virt_inspector.InstanceShutOffException(),
         ))
 
@@ -45,8 +43,8 @@ class TestMemoryPollster(base.TestPollsterBase):
         self.inspector.inspect_memory_usage = mock.Mock(
             side_effect=inspect_memory_usage)
 
-        mgr = manager.AgentManager()
-        pollster = memory.MemoryUsagePollster()
+        mgr = manager.AgentManager(0, self.CONF)
+        pollster = memory.MemoryUsagePollster(self.CONF)
 
         @mock.patch('ceilometer.compute.pollsters.memory.LOG')
         def _verify_memory_metering(expected_count, expected_memory_mb,
@@ -66,12 +64,27 @@ class TestMemoryPollster(base.TestPollsterBase):
         _verify_memory_metering(0, 0, 1)
         _verify_memory_metering(0, 0, 0)
 
+    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
+    def test_get_samples_with_empty_stats(self):
+
+        def inspect_memory_usage(instance, duration):
+            raise virt_inspector.NoDataException()
+
+        self.inspector.inspect_memory_usage = mock.Mock(
+            side_effect=inspect_memory_usage)
+
+        mgr = manager.AgentManager(0, self.CONF)
+        pollster = memory.MemoryUsagePollster(self.CONF)
+
+        def all_samples():
+            return list(pollster.get_samples(mgr, {}, [self.instance]))
+
+        self.assertRaises(plugin_base.PollsterPermanentError,
+                          all_samples)
+
 
 class TestResidentMemoryPollster(base.TestPollsterBase):
 
-    def setUp(self):
-        super(TestResidentMemoryPollster, self).setUp()
-
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def test_get_samples(self):
         next_value = iter((
@@ -91,8 +104,8 @@ class TestResidentMemoryPollster(base.TestPollsterBase):
         self.inspector.inspect_memory_resident = mock.Mock(
             side_effect=inspect_memory_resident)
 
-        mgr = manager.AgentManager()
-        pollster = memory.MemoryResidentPollster()
+        mgr = manager.AgentManager(0, self.CONF)
+        pollster = memory.MemoryResidentPollster(self.CONF)
 
         @mock.patch('ceilometer.compute.pollsters.memory.LOG')
         def _verify_resident_memory_metering(expected_count,
@@ -113,3 +126,59 @@ class TestResidentMemoryPollster(base.TestPollsterBase):
         _verify_resident_memory_metering(1, 2.0, 0)
         _verify_resident_memory_metering(0, 0, 1)
         _verify_resident_memory_metering(0, 0, 0)
+
+
+class TestMemoryBandwidthPollster(base.TestPollsterBase):
+
+    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
+    def test_get_samples(self):
+        next_value = iter((
+            virt_inspector.MemoryBandwidthStats(total=1892352, local=1802240),
+            virt_inspector.MemoryBandwidthStats(total=1081344, local=90112),
+        ))
+
+        def inspect_memory_bandwidth(instance, duration):
+            return next(next_value)
+
+        self.inspector.inspect_memory_bandwidth = mock.Mock(
+            side_effect=inspect_memory_bandwidth)
+        mgr = manager.AgentManager(0, self.CONF)
+
+        def _check_memory_bandwidth_total(expected_usage):
+            pollster = memory.MemoryBandwidthTotalPollster(self.CONF)
+
+            samples = list(pollster.get_samples(mgr, {}, [self.instance]))
+            self.assertEqual(1, len(samples))
+            self.assertEqual(set(['memory.bandwidth.total']),
+                             set([s.name for s in samples]))
+            self.assertEqual(expected_usage, samples[0].volume)
+
+        def _check_memory_bandwidth_local(expected_usage):
+            pollster = memory.MemoryBandwidthLocalPollster(self.CONF)
+
+            samples = list(pollster.get_samples(mgr, {}, [self.instance]))
+            self.assertEqual(1, len(samples))
+            self.assertEqual(set(['memory.bandwidth.local']),
+                             set([s.name for s in samples]))
+            self.assertEqual(expected_usage, samples[0].volume)
+
+        _check_memory_bandwidth_total(1892352)
+        _check_memory_bandwidth_local(90112)
+
+    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
+    def test_get_samples_with_empty_stats(self):
+
+        def inspect_memory_bandwidth(instance, duration):
+            raise virt_inspector.NoDataException()
+
+        self.inspector.inspect_memory_bandwidth = mock.Mock(
+            side_effect=inspect_memory_bandwidth)
+
+        mgr = manager.AgentManager(0, self.CONF)
+        pollster = memory.MemoryBandwidthTotalPollster(self.CONF)
+
+        def all_samples():
+            return list(pollster.get_samples(mgr, {}, [self.instance]))
+
+        self.assertRaises(plugin_base.PollsterPermanentError,
+                          all_samples)
