@@ -21,11 +21,13 @@ except ImportError:
 
 import fixtures
 import mock
+from oslo_config import fixture as fixture_config
 from oslo_utils import units
 from oslotest import base
 
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.compute.virt.libvirt import inspector as libvirt_inspector
+from ceilometer.compute.virt.libvirt import utils
 
 
 class TestLibvirtInspection(base.BaseTestCase):
@@ -35,42 +37,21 @@ class TestLibvirtInspection(base.BaseTestCase):
 
     def setUp(self):
         super(TestLibvirtInspection, self).setUp()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
 
         class VMInstance(object):
             id = 'ff58e738-12f4-4c58-acde-77617b68da56'
             name = 'instance-00000001'
         self.instance = VMInstance
-        self.inspector = libvirt_inspector.LibvirtInspector()
+        self.inspector = libvirt_inspector.LibvirtInspector(self.CONF)
         libvirt_inspector.libvirt = mock.Mock()
         libvirt_inspector.libvirt.VIR_DOMAIN_SHUTOFF = 5
         libvirt_inspector.libvirt.libvirtError = self.fakeLibvirtError
+        utils.libvirt = libvirt_inspector.libvirt
         self.domain = mock.Mock()
         self.addCleanup(mock.patch.stopall)
 
-    def test_inspect_cpus_stats(self):
-        fake_stats = [({}, {'vcpu.current': 2,
-                            'vcpu.maximum': 4,
-                            'vcpu.0.time': 10000,
-                            'vcpu.2.time': 10000,
-                            'vcpu.0.wait': 10000,
-                            'vcpu.2.wait': 10000,
-                            'cpu.time': 999999})]
-
-        with contextlib.ExitStack() as stack:
-            stack.enter_context(mock.patch.object(self.inspector.connection,
-                                                  'lookupByUUIDString',
-                                                  return_value=self.domain))
-            stack.enter_context(mock.patch.object(self.domain, 'info',
-                                                  return_value=(0, 0, 0,
-                                                                None, None)))
-            stack.enter_context(mock.patch.object(self.inspector.connection,
-                                                  'domainListGetStats',
-                                                  return_value=fake_stats))
-            cpu_info = self.inspector.inspect_cpus(self.instance)
-            self.assertEqual(2, cpu_info.number)
-            self.assertEqual(40000, cpu_info.time)
-
-    def test_inspect_cpus_stats_fallback_cpu_time(self):
+    def test_inspect_cpus(self):
         fake_stats = [({}, {'cpu.time': 999999, 'vcpu.current': 2})]
         with contextlib.ExitStack() as stack:
             stack.enter_context(mock.patch.object(self.inspector.connection,
@@ -374,6 +355,39 @@ class TestLibvirtInspection(base.BaseTestCase):
 
             self.assertEqual(0, len(disks))
 
+    def test_inspect_disk_info_without_source_element(self):
+        dom_xml = """
+             <domain type='kvm'>
+                 <devices>
+                    <disk type='file' device='cdrom'>
+                        <driver name='qemu' type='raw' cache='none'/>
+                        <backingStore/>
+                        <target dev='hdd' bus='ide' tray='open'/>
+                        <readonly/>
+                        <alias name='ide0-1-1'/>
+                        <address type='drive' controller='0' bus='1'
+                                 target='0' unit='1'/>
+                     </disk>
+                 </devices>
+             </domain>
+        """
+
+        with contextlib.ExitStack() as stack:
+            stack.enter_context(mock.patch.object(self.inspector.connection,
+                                                  'lookupByUUIDString',
+                                                  return_value=self.domain))
+            stack.enter_context(mock.patch.object(self.domain, 'XMLDesc',
+                                                  return_value=dom_xml))
+            stack.enter_context(mock.patch.object(self.domain, 'blockInfo',
+                                                  return_value=(1, 2, 3,
+                                                                -1)))
+            stack.enter_context(mock.patch.object(self.domain, 'info',
+                                                  return_value=(0, 0, 0,
+                                                                2, 999999)))
+            disks = list(self.inspector.inspect_disk_info(self.instance))
+
+            self.assertEqual(0, len(disks))
+
     def test_inspect_memory_usage_with_domain_shutoff(self):
         connection = self.inspector.connection
         with mock.patch.object(connection, 'lookupByUUIDString',
@@ -453,13 +467,15 @@ class TestLibvirtInspectionWithError(base.BaseTestCase):
 
     def setUp(self):
         super(TestLibvirtInspectionWithError, self).setUp()
-        self.inspector = libvirt_inspector.LibvirtInspector()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.inspector = libvirt_inspector.LibvirtInspector(self.CONF)
         self.useFixture(fixtures.MonkeyPatch(
             'ceilometer.compute.virt.libvirt.inspector.'
             'LibvirtInspector.connection',
             mock.MagicMock(side_effect=Exception('dummy'))))
         libvirt_inspector.libvirt = mock.Mock()
         libvirt_inspector.libvirt.libvirtError = self.fakeLibvirtError
+        utils.libvirt = libvirt_inspector.libvirt
 
     def test_inspect_unknown_error(self):
         self.assertRaises(virt_inspector.InspectorException,
