@@ -14,7 +14,7 @@
 # under the License.
 
 import mock
-from oslo_context import context
+from oslo_config import fixture as fixture_config
 from oslotest import base
 from oslotest import mockpatch
 
@@ -30,8 +30,8 @@ class _BaseTestFWPollster(base.BaseTestCase):
     def setUp(self):
         super(_BaseTestFWPollster, self).setUp()
         self.addCleanup(mock.patch.stopall)
-        self.context = context.get_admin_context()
-        self.manager = manager.AgentManager()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.manager = manager.AgentManager(0, self.CONF)
         plugin_base._get_keystone = mock.Mock()
         catalog = (plugin_base._get_keystone.session.auth.get_access.
                    return_value.service_catalog)
@@ -43,7 +43,7 @@ class TestFirewallPollster(_BaseTestFWPollster):
 
     def setUp(self):
         super(TestFirewallPollster, self).setUp()
-        self.pollster = fwaas.FirewallPollster()
+        self.pollster = fwaas.FirewallPollster(self.CONF)
         fake_fw = self.fake_get_fw_service()
         self.useFixture(mockpatch.Patch('ceilometer.neutron_client.Client.'
                                         'firewall_get_all',
@@ -106,7 +106,8 @@ class TestFirewallPollster(_BaseTestFWPollster):
                          set([s.name for s in samples]))
 
     def test_vpn_discovery(self):
-        discovered_fws = discovery.FirewallDiscovery().discover(self.manager)
+        discovered_fws = discovery.FirewallDiscovery(
+            self.CONF).discover(self.manager)
         self.assertEqual(3, len(discovered_fws))
 
         for vpn in self.fake_get_fw_service():
@@ -120,7 +121,7 @@ class TestIPSecConnectionsPollster(_BaseTestFWPollster):
 
     def setUp(self):
         super(TestIPSecConnectionsPollster, self).setUp()
-        self.pollster = fwaas.FirewallPolicyPollster()
+        self.pollster = fwaas.FirewallPolicyPollster(self.CONF)
         fake_fw_policy = self.fake_get_fw_policy()
         self.useFixture(mockpatch.Patch('ceilometer.neutron_client.Client.'
                                         'fw_policy_get_all',
@@ -165,7 +166,7 @@ class TestIPSecConnectionsPollster(_BaseTestFWPollster):
                          set([s.name for s in samples]))
 
     def test_fw_policy_discovery(self):
-        discovered_policy = discovery.FirewallPolicyDiscovery().discover(
-            self.manager)
+        discovered_policy = discovery.FirewallPolicyDiscovery(
+            self.CONF).discover(self.manager)
         self.assertEqual(1, len(discovered_policy))
         self.assertEqual(self.fake_get_fw_policy(), discovered_policy)
