@@ -14,7 +14,7 @@
 # under the License.
 
 import mock
-from oslo_context import context
+from oslo_config import fixture as fixture_config
 from oslotest import base
 from oslotest import mockpatch
 
@@ -30,8 +30,8 @@ class _BaseTestVPNPollster(base.BaseTestCase):
     def setUp(self):
         super(_BaseTestVPNPollster, self).setUp()
         self.addCleanup(mock.patch.stopall)
-        self.context = context.get_admin_context()
-        self.manager = manager.AgentManager()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.manager = manager.AgentManager(0, self.CONF)
         plugin_base._get_keystone = mock.Mock()
         catalog = (plugin_base._get_keystone.session.auth.get_access.
                    return_value.service_catalog)
@@ -43,7 +43,7 @@ class TestVPNServicesPollster(_BaseTestVPNPollster):
 
     def setUp(self):
         super(TestVPNServicesPollster, self).setUp()
-        self.pollster = vpnaas.VPNServicesPollster()
+        self.pollster = vpnaas.VPNServicesPollster(self.CONF)
         fake_vpn = self.fake_get_vpn_service()
         self.useFixture(mockpatch.Patch('ceilometer.neutron_client.Client.'
                                         'vpn_get_all',
@@ -110,8 +110,8 @@ class TestVPNServicesPollster(_BaseTestVPNPollster):
                          set([s.name for s in samples]))
 
     def test_vpn_discovery(self):
-        discovered_vpns = discovery.VPNServicesDiscovery().discover(
-            self.manager)
+        discovered_vpns = discovery.VPNServicesDiscovery(
+            self.CONF).discover(self.manager)
         self.assertEqual(3, len(discovered_vpns))
 
         for vpn in self.fake_get_vpn_service():
@@ -125,7 +125,7 @@ class TestIPSecConnectionsPollster(_BaseTestVPNPollster):
 
     def setUp(self):
         super(TestIPSecConnectionsPollster, self).setUp()
-        self.pollster = vpnaas.IPSecConnectionsPollster()
+        self.pollster = vpnaas.IPSecConnectionsPollster(self.CONF)
         fake_conns = self.fake_get_ipsec_connections()
         self.useFixture(mockpatch.Patch('ceilometer.neutron_client.Client.'
                                         'ipsec_site_connections_get_all',
@@ -150,6 +150,7 @@ class TestIPSecConnectionsPollster(_BaseTestVPNPollster):
                  'ipsecpolicy_id': 'fce3d818-fdcb-fg4b-de7f-7850dc8a9d7a',
                  'vpnservice_id': 'dce3d818-fdcb-fg4b-de7f-5650dc8a9d7a',
                  'admin_state_up': True,
+                 'status': 'ACTIVE',
                  'tenant_id': 'abe3d818-fdcb-fg4b-de7f-6650dc8a9d7a',
                  'id': 'fdfbcec-fdcb-fg4b-de7f-6650dc8a9d7a'}
                 ]
@@ -171,7 +172,7 @@ class TestIPSecConnectionsPollster(_BaseTestVPNPollster):
                          set([s.name for s in samples]))
 
     def test_conns_discovery(self):
-        discovered_conns = discovery.IPSecConnectionsDiscovery().discover(
-            self.manager)
+        discovered_conns = discovery.IPSecConnectionsDiscovery(
+            self.CONF).discover(self.manager)
         self.assertEqual(1, len(discovered_conns))
         self.assertEqual(self.fake_get_ipsec_connections(), discovered_conns)
