@@ -106,17 +106,47 @@ class NotifierOnlyPublisherTest(BasePublisherTestCase):
     @mock.patch('oslo_messaging.Notifier')
     def test_publish_topic_override(self, notifier):
         msg_publisher.SampleNotifierPublisher(
+            self.CONF,
             netutils.urlsplit('notifier://?topic=custom_topic'))
-        notifier.assert_called_with(mock.ANY, topic='custom_topic',
+        notifier.assert_called_with(mock.ANY, topics=['custom_topic'],
                                     driver=mock.ANY, retry=mock.ANY,
                                     publisher_id=mock.ANY)
 
         msg_publisher.EventNotifierPublisher(
+            self.CONF,
             netutils.urlsplit('notifier://?topic=custom_event_topic'))
-        notifier.assert_called_with(mock.ANY, topic='custom_event_topic',
+        notifier.assert_called_with(mock.ANY, topics=['custom_event_topic'],
                                     driver=mock.ANY, retry=mock.ANY,
                                     publisher_id=mock.ANY)
 
+    @mock.patch('ceilometer.messaging.get_transport')
+    def test_publish_other_host(self, cgt):
+        msg_publisher.SampleNotifierPublisher(
+            self.CONF,
+            netutils.urlsplit('notifier://foo:foo@127.0.0.1:1234'))
+        cgt.assert_called_with(self.CONF, 'rabbit://foo:foo@127.0.0.1:1234')
+
+        msg_publisher.EventNotifierPublisher(
+            self.CONF,
+            netutils.urlsplit('notifier://foo:foo@127.0.0.1:1234'))
+        cgt.assert_called_with(self.CONF, 'rabbit://foo:foo@127.0.0.1:1234')
+
+    @mock.patch('ceilometer.messaging.get_transport')
+    def test_publish_other_host_vhost_and_query(self, cgt):
+        msg_publisher.SampleNotifierPublisher(
+            self.CONF,
+            netutils.urlsplit('notifier://foo:foo@127.0.0.1:1234/foo'
+                              '?driver=amqp&amqp_auto_delete=true'))
+        cgt.assert_called_with(self.CONF, 'amqp://foo:foo@127.0.0.1:1234/foo'
+                               '?amqp_auto_delete=true')
+
+        msg_publisher.EventNotifierPublisher(
+            self.CONF,
+            netutils.urlsplit('notifier://foo:foo@127.0.0.1:1234/foo'
+                              '?driver=amqp&amqp_auto_delete=true'))
+        cgt.assert_called_with(self.CONF, 'amqp://foo:foo@127.0.0.1:1234/foo'
+                               '?amqp_auto_delete=true')
+
 
 class TestPublisher(testscenarios.testcase.WithScenarios,
                     BasePublisherTestCase):
@@ -144,6 +174,7 @@ class TestPublisherPolicy(TestPublisher):
     @mock.patch('ceilometer.publisher.messaging.LOG')
     def test_published_with_no_policy(self, mylog):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://' % self.protocol))
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
@@ -151,16 +182,17 @@ class TestPublisherPolicy(TestPublisher):
             self.assertRaises(
                 msg_publisher.DeliveryFailure,
                 getattr(publisher, self.pub_func),
-                mock.MagicMock(), self.test_data)
+                self.test_data)
             self.assertTrue(mylog.info.called)
             self.assertEqual('default', publisher.policy)
             self.assertEqual(0, len(publisher.local_queue))
             fake_send.assert_called_once_with(
-                mock.ANY, self.topic, mock.ANY)
+                self.topic, mock.ANY)
 
     @mock.patch('ceilometer.publisher.messaging.LOG')
     def test_published_with_policy_block(self, mylog):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=default' % self.protocol))
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
@@ -168,15 +200,16 @@ class TestPublisherPolicy(TestPublisher):
             self.assertRaises(
                 msg_publisher.DeliveryFailure,
                 getattr(publisher, self.pub_func),
-                mock.MagicMock(), self.test_data)
+                self.test_data)
             self.assertTrue(mylog.info.called)
             self.assertEqual(0, len(publisher.local_queue))
             fake_send.assert_called_once_with(
-                mock.ANY, self.topic, mock.ANY)
+                self.topic, mock.ANY)
 
     @mock.patch('ceilometer.publisher.messaging.LOG')
     def test_published_with_policy_incorrect(self, mylog):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=notexist' % self.protocol))
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
@@ -184,12 +217,12 @@ class TestPublisherPolicy(TestPublisher):
             self.assertRaises(
                 msg_publisher.DeliveryFailure,
                 getattr(publisher, self.pub_func),
-                mock.MagicMock(), self.test_data)
+                self.test_data)
             self.assertTrue(mylog.warning.called)
             self.assertEqual('default', publisher.policy)
             self.assertEqual(0, len(publisher.local_queue))
             fake_send.assert_called_once_with(
-                mock.ANY, self.topic, mock.ANY)
+                self.topic, mock.ANY)
 
 
 @mock.patch('ceilometer.publisher.messaging.LOG', mock.Mock())
@@ -197,56 +230,55 @@ class TestPublisherPolicyReactions(TestPublisher):
 
     def test_published_with_policy_drop_and_rpc_down(self):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=drop' % self.protocol))
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
             fake_send.side_effect = side_effect
-            getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                              self.test_data)
+            getattr(publisher, self.pub_func)(self.test_data)
             self.assertEqual(0, len(publisher.local_queue))
             fake_send.assert_called_once_with(
-                mock.ANY, self.topic, mock.ANY)
+                self.topic, mock.ANY)
 
     def test_published_with_policy_queue_and_rpc_down(self):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=queue' % self.protocol))
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
             fake_send.side_effect = side_effect
 
-            getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                              self.test_data)
+            getattr(publisher, self.pub_func)(self.test_data)
             self.assertEqual(1, len(publisher.local_queue))
             fake_send.assert_called_once_with(
-                mock.ANY, self.topic, mock.ANY)
+                self.topic, mock.ANY)
 
     def test_published_with_policy_queue_and_rpc_down_up(self):
         self.rpc_unreachable = True
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=queue' % self.protocol))
 
         side_effect = msg_publisher.DeliveryFailure()
         with mock.patch.object(publisher, '_send') as fake_send:
             fake_send.side_effect = side_effect
-            getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                              self.test_data)
+            getattr(publisher, self.pub_func)(self.test_data)
 
             self.assertEqual(1, len(publisher.local_queue))
 
             fake_send.side_effect = mock.MagicMock()
-            getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                              self.test_data)
+            getattr(publisher, self.pub_func)(self.test_data)
 
             self.assertEqual(0, len(publisher.local_queue))
 
             topic = self.topic
-            expected = [mock.call(mock.ANY, topic, mock.ANY),
-                        mock.call(mock.ANY, topic, mock.ANY),
-                        mock.call(mock.ANY, topic, mock.ANY)]
+            expected = [mock.call(topic, mock.ANY),
+                        mock.call(topic, mock.ANY),
+                        mock.call(topic, mock.ANY)]
             self.assertEqual(expected, fake_send.mock_calls)
 
     def test_published_with_policy_sized_queue_and_rpc_down(self):
-        publisher = self.publisher_cls(netutils.urlsplit(
+        publisher = self.publisher_cls(self.CONF, netutils.urlsplit(
             '%s://?policy=queue&max_queue_length=3' % self.protocol))
 
         side_effect = msg_publisher.DeliveryFailure()
@@ -255,25 +287,25 @@ class TestPublisherPolicyReactions(TestPublisher):
             for i in range(0, 5):
                 for s in self.test_data:
                     setattr(s, self.attr, 'test-%d' % i)
-                getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                                  self.test_data)
+                getattr(publisher, self.pub_func)(self.test_data)
 
         self.assertEqual(3, len(publisher.local_queue))
         self.assertEqual(
             'test-2',
-            publisher.local_queue[0][2][0][self.attr]
+            publisher.local_queue[0][1][0][self.attr]
         )
         self.assertEqual(
             'test-3',
-            publisher.local_queue[1][2][0][self.attr]
+            publisher.local_queue[1][1][0][self.attr]
         )
         self.assertEqual(
             'test-4',
-            publisher.local_queue[2][2][0][self.attr]
+            publisher.local_queue[2][1][0][self.attr]
         )
 
     def test_published_with_policy_default_sized_queue_and_rpc_down(self):
         publisher = self.publisher_cls(
+            self.CONF,
             netutils.urlsplit('%s://?policy=queue' % self.protocol))
 
         side_effect = msg_publisher.DeliveryFailure()
@@ -282,15 +314,14 @@ class TestPublisherPolicyReactions(TestPublisher):
             for i in range(0, 2000):
                 for s in self.test_data:
                     setattr(s, self.attr, 'test-%d' % i)
-                getattr(publisher, self.pub_func)(mock.MagicMock(),
-                                                  self.test_data)
+                getattr(publisher, self.pub_func)(self.test_data)
 
         self.assertEqual(1024, len(publisher.local_queue))
         self.assertEqual(
             'test-976',
-            publisher.local_queue[0][2][0][self.attr]
+            publisher.local_queue[0][1][0][self.attr]
         )
         self.assertEqual(
             'test-1999',
-            publisher.local_queue[1023][2][0][self.attr]
+            publisher.local_queue[1023][1][0][self.attr]
         )
