@@ -18,7 +18,6 @@ import uuid
 import mock
 from oslo_config import fixture as fixture_config
 import oslo_messaging
-from oslotest import base
 from oslotest import mockpatch
 
 from ceilometer.event.storage import models
@@ -27,16 +26,18 @@ from ceilometer import publisher
 from ceilometer.publisher import test as test_publisher
 from ceilometer.publisher import utils
 
+from ceilometer.tests import base
+
 
 class EventPipelineTestCase(base.BaseTestCase):
 
-    def get_publisher(self, url, namespace=''):
+    def get_publisher(self, conf, url, namespace=''):
         fake_drivers = {'test://': test_publisher.TestPublisher,
                         'new://': test_publisher.TestPublisher,
                         'except://': self.PublisherClassException}
-        return fake_drivers[url](url)
+        return fake_drivers[url](conf, url)
 
-    class PublisherClassException(publisher.PublisherBase):
+    class PublisherClassException(publisher.ConfigPublisherBase):
         def publish_samples(self, samples):
             pass
 
@@ -45,6 +46,9 @@ class EventPipelineTestCase(base.BaseTestCase):
 
     def setUp(self):
         super(EventPipelineTestCase, self).setUp()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF([])
+
         self.p_type = pipeline.EVENT_TYPE
         self.transformer_manager = None
 
@@ -84,7 +88,7 @@ class EventPipelineTestCase(base.BaseTestCase):
             'ceilometer.pipeline.LOG.exception',
             side_effect=self._handle_reraise_exception))
 
-    def _handle_reraise_exception(self, msg):
+    def _handle_reraise_exception(self, *args, **kwargs):
         if self._reraise_exception:
             raise Exception(traceback.format_exc())
 
@@ -150,7 +154,8 @@ class EventPipelineTestCase(base.BaseTestCase):
     def _exception_create_pipelinemanager(self):
         self.assertRaises(pipeline.PipelineException,
                           pipeline.PipelineManager,
-                          self.pipeline_cfg,
+                          self.CONF,
+                          self.cfg2file(self.pipeline_cfg),
                           self.transformer_manager,
                           self.p_type)
 
@@ -163,9 +168,11 @@ class EventPipelineTestCase(base.BaseTestCase):
         self._exception_create_pipelinemanager()
 
     def test_name(self):
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         for pipe in pipeline_manager.pipelines:
             self.assertTrue(pipe.name.startswith('event:'))
 
@@ -195,9 +202,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_multiple_included_events(self):
         event_cfg = ['a', 'b']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
 
         with pipeline_manager.publisher() as p:
             p([self.test_event])
@@ -215,9 +224,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_event_non_match(self):
         event_cfg = ['nomatch']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event])
 
@@ -228,9 +239,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_wildcard_event(self):
         event_cfg = ['*']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event])
 
@@ -241,17 +254,21 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_wildcard_excluded_events(self):
         event_cfg = ['*', '!a']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         self.assertFalse(pipeline_manager.pipelines[0].support_event('a'))
 
     def test_wildcard_excluded_events_not_excluded(self):
         event_cfg = ['*', '!b']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event])
         publisher = pipeline_manager.pipelines[0].publishers[0]
@@ -261,9 +278,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_all_excluded_events_not_excluded(self):
         event_cfg = ['!b', '!c']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event])
 
@@ -274,9 +293,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_all_excluded_events_excluded(self):
         event_cfg = ['!a', '!c']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         self.assertFalse(pipeline_manager.pipelines[0].support_event('a'))
         self.assertTrue(pipeline_manager.pipelines[0].support_event('b'))
         self.assertFalse(pipeline_manager.pipelines[0].support_event('c'))
@@ -284,9 +305,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_wildcard_and_excluded_wildcard_events(self):
         event_cfg = ['*', '!compute.*']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         self.assertFalse(pipeline_manager.pipelines[0].
                          support_event('compute.instance.create.start'))
         self.assertTrue(pipeline_manager.pipelines[0].
@@ -295,9 +318,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_included_event_and_wildcard_events(self):
         event_cfg = ['compute.instance.create.start', 'identity.*']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         self.assertTrue(pipeline_manager.pipelines[0].
                         support_event('identity.user.create'))
         self.assertTrue(pipeline_manager.pipelines[0].
@@ -308,9 +333,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_excluded_event_and_excluded_wildcard_events(self):
         event_cfg = ['!compute.instance.create.start', '!identity.*']
         self._set_pipeline_cfg('events', event_cfg)
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         self.assertFalse(pipeline_manager.pipelines[0].
                          support_event('identity.user.create'))
         self.assertFalse(pipeline_manager.pipelines[0].
@@ -321,9 +348,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_multiple_pipeline(self):
         self._augment_pipeline_cfg()
 
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event, self.test_event2])
 
@@ -338,9 +367,11 @@ class EventPipelineTestCase(base.BaseTestCase):
 
     def test_multiple_publisher(self):
         self._set_pipeline_cfg('publishers', ['test://', 'new://'])
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
 
         with pipeline_manager.publisher() as p:
             p([self.test_event])
@@ -355,9 +386,11 @@ class EventPipelineTestCase(base.BaseTestCase):
     def test_multiple_publisher_isolation(self):
         self._reraise_exception = False
         self._set_pipeline_cfg('publishers', ['except://', 'new://'])
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         with pipeline_manager.publisher() as p:
             p([self.test_event])
 
@@ -370,8 +403,6 @@ class EventPipelineTestCase(base.BaseTestCase):
         self._exception_create_pipelinemanager()
 
     def test_event_pipeline_endpoint_requeue_on_failure(self):
-        self.CONF = self.useFixture(fixture_config.Config()).conf
-        self.CONF([])
 
         self.CONF.set_override("ack_on_event_error", False,
                                group="notification")
@@ -397,9 +428,11 @@ class EventPipelineTestCase(base.BaseTestCase):
             'ceilometer.publisher.test.TestPublisher',
             return_value=fake_publisher))
 
-        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
-                                                    self.transformer_manager,
-                                                    self.p_type)
+        pipeline_manager = pipeline.PipelineManager(
+            self.CONF,
+            self.cfg2file(self.pipeline_cfg),
+            self.transformer_manager,
+            self.p_type)
         event_pipeline_endpoint = pipeline.EventPipelineEndpoint(
             pipeline_manager.pipelines[0])
 
